<?php
/**
 * sql2excelcategory controller for the SQL 2 Excel component
 * 
 * @license		GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );



class Sql2excelControllerSqlexcelupgrade extends Sql2excelController
{
	/**
	 * constructor (registers additional tasks to methods)
	 * @return void
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra tasks
		$this->registerTask( 'upgrade'  , 	'upgrade' );
	}


	/**
	 * Public
	 *
	 * Perform Database upgrade
	 * @return void
	 */
	function upgrade()
	{

		// Version 0.9.2
		$res = $this->_addColumn('#__sql2excel_worksheets', 'formulas', "VARCHAR(255) NOT NULL DEFAULT ''");
		
		// Version 1.1.4
		if ( $res ) {
			$res = $this->_addColumn('#__sql2excel_workbooks', 'description', "TEXT NOT NULL DEFAULT ''");
			if ( ! $res ) {
				$msg .= JText::_( 'Failed to add "description" column to #__sql2excel_workbooks table.' );
			} else {
				$res = $this->_addColumn('#__sql2excel_workbooks', 'keywords', "VARCHAR(255) NOT NULL DEFAULT ''");
				if ( ! $res ) {
					$msg .= JText::_( 'Failed to add "keywords" column to #__sql2excel_workbooks table.' );
				} else {
					$msg = JText::_( 'Upgrade Successful!' );
				}
			}
		} else {
			$msg = JText::_( 'ERROR: Upgrade Failed! Failed to add "formulas" column to #__sql2excel_worksheets table.' );
		}


		// Version 1.1.5
		if ( $err == '' ) {
			$res = $this->_addColumn('#__sql2excel_worksheets', 'preview_rows', "int(11) unsigned default NULL");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "preview_rows" column to #__sql2excel_worksheets table.' );
			}
			$res = $this->_addColumn('#__sql2excel_worksheets', 'preview_formulas', "ENUM('Global','Show','Label','Hide') NOT NULL default 'Global'");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "preview_formulas" column to #__sql2excel_worksheets table.' );
			}
			$res = $this->_addColumn('#__sql2excel_worksheets', 'preview_hidecols', "VARCHAR(255) NOT NULL default ''");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "preview_hidecols" column to #__sql2excel_worksheets table.' );
			}			
		}
		
		// 1.4.0
		if ( $err == '' ) {
			$query = "CREATE TABLE `#__sql2excel_settings` (
						  `param` VARCHAR(40) NOT NULL,
						  `value` TEXT NOT NULL default '',
						  PRIMARY KEY  (`param`)
						) ENGINE=MyISAM DEFAULT CHARSET=utf8";

			$res = $this->_addTable('#__sql2excel_settings', $query);	
			if ( ! $res ) {
				$err .= JText::_( 'Failed to create "__sql2excel_settings" table.' );
			}
		}		


		// 1.5.0
		if ( $err == '' ) {		
			$res = $this->_addColumn('#__sql2excel_worksheets', 'header_parms', "VARCHAR(255) NOT NULL DEFAULT 'Arial,10,normal,black,none'");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "header_parms" column to #__sql2excel_worksheets table.' );
			}
			$res = $this->_addColumn('#__sql2excel_worksheets', 'data_parms', "VARCHAR(255) NOT NULL DEFAULT 'Arial,10,normal,black,None,none,1,silver,1'");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "data_parms" column to #__sql2excel_worksheets table.' );
			}
			$res = $this->_addColumn('#__sql2excel_worksheets', 'footer_parms', "VARCHAR(255) NOT NULL DEFAULT 'Arial,10,normal,black,none'");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "footer_parms" column to #__sql2excel_worksheets table.' );
			}
		}

		// 1.6.0
		if ( $err == '' ) {		
			$res = $this->_addColumn('#__sql2excel_worksheets', 'print_parms', "VARCHAR(255) NOT NULL default '0.75,0.75,1.0,1.0,0,0,0,0,0'");
			if ( ! $res ) {
				$err .= JText::_( 'Failed to add "print_parms" column to #__sql2excel_worksheets table.' );
			}
		}

			
		$this->setRedirect( 'index.php?option=com_sql2excel', $msg );
	}


	/**
	 * Private function
	 *
	 * Adds a column to a table, if not exists
	 * @return boolean
	 */
	function _addColumn($table, $colName, $colAttr = "INT( 11 ) NOT NULL DEFAULT '0'" ) {
		
		global $mainframe;
		$db =& JFactory::getDBO();
		$colExists = false;

		$query = 'SHOW COLUMNS FROM ' . $table;
		$db->setQuery( $query );
		if (!$result = $db->query()){return false;}
		$columnData = $db->loadObjectList();
		
		
		foreach ($columnData as $currCol) {
			if ($currCol->Field == $colName) {
				$colExists = true;
				break;
			}
		}
		
		if (!$colExists) {
			$query = "ALTER TABLE `".$table."` ADD `" . $colName . "` " . $colAttr;
			$db->setQuery( $query );
			if (!$result = $db->query()){
				return false;
			}
		}
				
		return true;
	}
	

	/**
	 * Private function
	 *
	 * Adds a table, if not exists
	 * @return boolean
	 */
	function _addTable($tableName, $sql) {
		$db =& JFactory::getDBO();
		if ( ! $this->_tableExists($tableName) ) {
			$db->setQuery( $sql );
			if (!$result = $db->query()){
				return false;
			}
		}
		return true;
	}

	
	/**
	 * Private function
	 *
	 * Checks if a table exists
	 * @return boolean
	 */	
	function _tableExists($tableName) {
		$db	= & JFactory::getDBO();	
		$prefix = $db->_table_prefix;
		$tableName = str_replace('#__', $prefix, $tableName);
		$tableList = $db->getTableList($db);		
		if ( in_array($tableName,$tableList) ) {
			return true;
		} else {
			return false;
		}
	}	

}
