<?php
/*
 * @package Joomla 1.5
 * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 *
 * @component SQL 2 Excel Component
 * @copyright Copyright (C) Joomla-R-Us, joomla-r-us.com
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

class Sql2excelModelSqlexcelcategories extends JModel
{

	var $_data	= null;
	var $_pagination = null;

	function __construct()
	{
		parent::__construct();
		global $mainframe, $option;		
		// Get the pagination request variables
		$limit		= $mainframe->getUserStateFromRequest( 'global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int' );
		$limitstart	= $mainframe->getUserStateFromRequest( $option.'.limitstart', 'limitstart', 0, 'int' );

		// In case limit has been changed, adjust limitstart accordingly
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}


	/**
	 * Returns the query
	 * @return string The query to be used to retrieve the rows from the database
	 */
	function _buildQuery()
	{
		global $mainframe;
		$where = array();

		$context			= 'com_sql2excel.sqlexcelcategories.list.';

		// Get sort order
		$filter_Column	= $mainframe->getUserStateFromRequest( 
							$context.'filter_order',
							'filter_order',	
							'a.ordering',
							'cmd' );
		$sort_Order	= $mainframe->getUserStateFromRequest( 
							$context.'filter_order_Dir',	
							'filter_order_Dir',	
							'',				
							'word' );

		if ( $filter_Column == '' ) { $filter_Column = 'a.ordering'; }

		// Published / Unpublished State
		$filter_state	= $mainframe->getUserStateFromRequest( 
							$context.'filter_state',
							'filter_state',	
							'',
							'word' );
														
		if ( $filter_state ) {
			if ( $filter_state == 'P' ) {
				$where[] = 'a.published = 1';
			} else if ($filter_state == 'U' ) {
				$where[] = 'a.published = 0';
			}
		}
		

		$filter_sectionid	= $mainframe->getUserStateFromRequest( 
							$context.'filter_sectionid',	
							'filter_sectionid',	
							'',				
							'int' );
		if ( $filter_sectionid ) {
			$where[] = 'a.section=' . $filter_sectionid;
		}
		

		// Get search string
		$searchStr = $mainframe->getUserStateFromRequest( 
							$context.'search',
							'search',
							'',
							'string' );

		$searchStr = JString::strtolower( $searchStr );
		

		if ($searchStr) {
			$where[] = 'LOWER(a.title) LIKE '.$this->_db->Quote('%'.$searchStr.'%');
		}

		$where[] = 'b.id = a.access';
		$where[] = 'c.id = a.section';
		$where 	= ' WHERE ' . implode(' AND ', $where);
		
		
		// Assemble it all to a SQL query
		$query =  ' SELECT a.*, b.name as groupname, c.title as sectionname '
			. ' FROM #__sql2excel_categories a, #__groups b, #__sql2excel_sections c ' 
			. $where
			. ' ORDER BY ' . $filter_Column . ' ' . $sort_Order;

		return $query;
	}

	/**
	 * @return array Array of objects containing the data from the database
	 */
	function getData()
	{
		if (empty($this->_data)){
			$query 		 = $this->_buildQuery();
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
		}
	
		return $this->_data;
	}
	
	
	/**
	 * @return number of objects
	 */
	function getTotal()
	{
		if (empty($this->_total)) {
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}
		return $this->_total;
	}

	/**
	 * @return pagination for the recordset
	 */
	function getPagination()
	{
		if (empty($this->_pagination)) {
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
	

	/**
	 * Method to get list of Sections for the filter
	 * @return object with data
	 */
	function getSectionFilter($selected)
	{
		// Get list of sections
		$db	= & JFactory::getDBO();		
		$query = ' SELECT ID AS value, TITLE AS text ' .
			 ' FROM #__sql2excel_sections ' .
			 ' ORDER BY TITLE';
		$this->_db->setQuery( $query );
		$mysections[] = JHTML::_('select.option', '0', '- '.JText::_('Select Section').' -');
		$sections = array_merge($mysections, $db->loadObjectList());
				
		$sectionFilter = JHTML::_( 'select.genericlist', 
					 $sections, 
					 'filter_sectionid',  
					 'onchange="document.adminForm.submit();"' , 
					 'value', 
					 'text',
					 $selected );
		return $sectionFilter;
	}	
	
	
}