<?php
/*
 * @package Joomla 1.5
 * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 *
 * @component SQL 2 Excel Component
 * @copyright Copyright (C) Joomla-R-Us, joomla-r-us.com
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

require_once( JPATH_ADMINISTRATOR.DS.'components'.DS.'com_sql2excel'.DS.'helpers'.DS.'sql2excel.php' );


class Sql2excelModelSqlexcelworkbook extends JModel
{
	var $_wbID;
	var $_wbData;

	/**
	 * Constructor that retrieves the ID from the request
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	function setId($id)
	{
		// Set id and wipe data
		$this->_wbID		= $id;
		$this->_wbData	= null;
	}

	/**
	 * Method to get list of Sections
	 * @return select list (html)
	 */
	function getSectionOptions($selected)
	{
		// Get list of sections
		$db	= & JFactory::getDBO();		
		$query = ' SELECT ID AS value, TITLE AS text ' .
			 ' FROM #__sql2excel_sections ' .
			 ' ORDER BY TITLE';
		$this->_db->setQuery( $query );
		$mysections[] = JHTML::_('select.option', '0', '- '.JText::_('Please Select').' -');
		$sections = array_merge($mysections, $db->loadObjectList());
		$sectionsOpt = JHTML::_( 'select.genericlist', 
					 $sections, 
					 'section',  
					 'class="inputbox" size="1" onchange="changeDynaList( \'category\', categoryArray, document.adminForm.section.options[document.adminForm.section.selectedIndex].value, 0, 0);checkSection(this);"', 
					 'value', 
					 'text',
					 $selected );
		return $sectionsOpt;
	}

	/**
	 * Method to get list of Categories
	 * @return select list (html)
	 */
	function getCategoryOptions($sectionid, $catid)
	{
	
		// Get list of categories for the selected section
		$mycategories[] = JHTML::_('select.option', '0', '- '.JText::_('Please Select').' -');
		if ( $sectionid > 0 ) {
			$db	= & JFactory::getDBO();		
			$query = ' SELECT ID AS value, TITLE AS text ' .
			 	' FROM #__sql2excel_categories ' .
			 	' WHERE section=' . $sectionid  .
			 	' ORDER BY TITLE';
			$this->_db->setQuery( $query );
		
			$categories = array_merge($mycategories, $db->loadObjectList());
		} else { $categories = $mycategories; }
		
		$categoryOpt = JHTML::_( 'select.genericlist', 
					 $categories, 
					 'category',  
					 'class="inputbox" size="1" check_required(\'category_req_div\',this,\'0\');' ,  
					 'value', 
					 'text',
					 $catid );
		return $categoryOpt;
	}


	/**
	 * Method to get Javascript array with all Categories vs Sections
	 * @return Javascript snippet
	 */
	function getCategoryArray()
	{
	
		// Get list of categories for the selected section
		$mycategories = "var categoryArray = new Array;\ncategoryArray[0] = new Array( '0','0','- Please Select -' );";


		$db	= & JFactory::getDBO();		
		$query = ' SELECT ID, TITLE, SECTION ' .
			 	 ' FROM #__sql2excel_categories ' .
			 	 ' ORDER BY SECTION, TITLE';
		$this->_db->setQuery( $query );
		
		$categories = $db->loadObjectList();
		$i=1;
		foreach ( $categories as $cat ) {
			$mycategories = $mycategories . "\ncategoryArray[" . $i . "]=new Array('" . $cat->SECTION . "','" . $cat->ID . "','" . str_replace("'", '',$cat->TITLE) . "');"; 
			$i++;
		}		
		return $mycategories;
	}
	
	

	/**
	 * Method to get list of Worksheets
	 * @return select list (html)
	 */
	function getWorksheetList($id, $width)
	{
		if ( $width == '' ) { $width = 300; };

		// Get list of sections
		$db	= & JFactory::getDBO();	
		if ( $id == 0 ) {
			$query = " SELECT ID AS value, CONCAT(ID, ' : ', TITLE, ' : ', sheetname ) AS text " .
			 	' FROM #__sql2excel_worksheets ' .
			 	' ORDER BY ID';
		} else {
			$query = " SELECT ID AS value, CONCAT(ID, ' : ', TITLE, ' : ', sheetname ) AS text " .
			 	' FROM #__sql2excel_worksheets ' .
			 	' WHERE ID NOT IN ( 	SELECT ws_id AS ID 
			 				FROM #__sql2excel_worksheet2book
			 				WHERE wb_id=' . $id . ') ' .
			 	' ORDER BY ID';
		
		}
		$this->_db->setQuery( $query );
		$workSheets = JHTML::_( 'select.genericlist', 
					 $db->loadObjectList(), 
					 'available_worksheets',  
					 'class="inputbox" style="width: ' . $width . 'px" size="20" onDblClick="addWS();"', 
					 'value', 
					 'text');
		return $workSheets;
	}


	/**
	 * Method to get list of Worksheets for a Workbook
	 * @return select list (html)
	 */
	function getSelWorksheetList($currWBid, $width)
	{
		if ( $width == '' ) { $width = 300; };
		
		// Get list of sections
		$db	= & JFactory::getDBO();		
		$query = " SELECT a.ID AS value, CONCAT(a.ID, ' : ', a.TITLE, ' : ', a.sheetname ) AS text " .
			 ' FROM #__sql2excel_worksheets a, #__sql2excel_worksheet2book b' .
			 ' WHERE a.id = b.ws_id AND b.wb_id=' . $currWBid .
			 ' ORDER BY b.ordering';
		$this->_db->setQuery( $query );
		$workSheets = JHTML::_( 'select.genericlist', 
					 $db->loadObjectList(), 
					 'selected_worksheets',  
					 'class="inputbox" style="width: ' . $width . 'px" size="20" onDblClick="remWS();"', 
					 'value', 
					 'text');

		return $workSheets;
	}
	

	/**
	 * Method to get list of Worksheets for a Workbook
	 * @return select list (html)
	 */
	function getNumberSelWorksheets($currWBid)
	{		
		// Get list of sections
		$db	= & JFactory::getDBO();		
		$query = " SELECT COUNT(a.id) AS CNT " .
			 ' FROM #__sql2excel_worksheets a, #__sql2excel_worksheet2book b' .
			 ' WHERE a.id = b.ws_id AND b.wb_id=' . $currWBid;
			 
		$this->_db->setQuery( $query );
		$result = $this->_db->loadResult();
		return $result;
	}
		
		
	/**
	 * Method to get list of available colors
	 * @return select list (html)
	 */
	function getExcelColors($name, $selected)
	{
		// Supported colors for Excel Writer
		$mycolors[] = JHTML::_('select.option', 'aqua', 'Aqua');
		$mycolors[] = JHTML::_('select.option', 'black', 'Black');
		$mycolors[] = JHTML::_('select.option', 'blue', 'Blue');
		$mycolors[] = JHTML::_('select.option', 'brown', 'Brown');
		$mycolors[] = JHTML::_('select.option', 'cyan', 'Cyan');
		$mycolors[] = JHTML::_('select.option', 'grey', 'Grey');
		$mycolors[] = JHTML::_('select.option', 'lime', 'Lime');
		$mycolors[] = JHTML::_('select.option', 'magenta', 'Magenta');
		$mycolors[] = JHTML::_('select.option', 'navy', 'Navy');
		$mycolors[] = JHTML::_('select.option', 'orange', 'Orange');
		$mycolors[] = JHTML::_('select.option', 'purple', 'Purple');
		$mycolors[] = JHTML::_('select.option', 'red', 'Red');
		$mycolors[] = JHTML::_('select.option', 'silver', 'Silver');
		$mycolors[] = JHTML::_('select.option', 'white', 'White');
		$mycolors[] = JHTML::_('select.option', 'yellow', 'Yellow');

		$colorsOpt = JHTML::_( 'select.genericlist', 
					 $mycolors, 
					 $name,  
					 'class="inputbox" size="1"' , 
					 'value', 
					 'text',
					 $selected );
		return $colorsOpt;
	}

	/**
	 * Method to get list of available colors
	 * @return select list (html)
	 */
	function getExcelTextSizes($name, $selected)
	{
		// Supported colors for Excel Writer
		$mysizes[] = JHTML::_('select.option', '6', '6');
		$mysizes[] = JHTML::_('select.option', '7', '7');
		$mysizes[] = JHTML::_('select.option', '8', '8');
		$mysizes[] = JHTML::_('select.option', '10', '10');
		$mysizes[] = JHTML::_('select.option', '12', '12');
		$mysizes[] = JHTML::_('select.option', '14', '14');
		$mysizes[] = JHTML::_('select.option', '16', '16');
		$mysizes[] = JHTML::_('select.option', '18', '18');
		$mysizes[] = JHTML::_('select.option', '20', '20');
		$mysizes[] = JHTML::_('select.option', '22', '22');
		$mysizes[] = JHTML::_('select.option', '24', '24');

		$colorsOpt = JHTML::_( 'select.genericlist', 
					 $mysizes, 
					 $name,  
					 'class="inputbox" size="1"' , 
					 'value', 
					 'text',
					 $selected );
		return $colorsOpt;
	}


	/**
	 * Method to get data
	 * @return object with data
	 */
	function &getData()
	{

		// Load the data
		if (empty( $this->_wbData )) {
			$query = ' SELECT * FROM #__sql2excel_workbooks ' .
				 ' WHERE id = '.$this->_wbID;
			$this->_db->setQuery( $query );
			$this->_wbData = $this->_db->loadObject();
		}
		if (!$this->_wbData) {
			$sql2excel = new stdClass();
			$sql2excel->id			= 0;
			$sql2excel->title		= null;
			$sql2excel->link_title		= null;
			$sql2excel->filename		= null;
			$sql2excel->section		= null;
			$sql2excel->category		= null;
			$sql2excel->published		= 1;
			$sql2excel->checked_out		= 0;
			$sql2excel->checked_out_time	= null;	
			$sql2excel->created		= null;	
			$sql2excel->access		= 0;		
			$sql2excel->count		= 0;
			$sql2excel->ordering		= 0;
			$sql2excel->description		= null;
			$sql2excel->keywords		= null;
			
			$this->_wbData		= $sql2excel;  
		}
		return $this->_wbData;
	}
	  
	
	/**
	 * Method to check if a workbook is checked out or not
	 *
	 * @access	public
	 * @return	boolean	True if it is checked out
	 */
	function isCheckedOut( $uid=0 ) {
		if ($this->_loadData()) {
			if ($uid) {
				return ($this->_wbData->checked_out && $this->_wbData->checked_out != $uid);
			} else {
				return $this->_wbData->checked_out;
			}
		}
	}

	/**
	 * Method to checkin a workbook
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function checkin() {
		if ($this->_wbID ) {
			$cattable = & $this->getTable();
			if(! $cattable->checkin($this->_wbID)) {
				$this->setError('<p>Checkin failed!</p><p>' . $this->_db->getErrorMsg());
				return false;
			}
		}
		return false;
	}

	/**
	 * Method to checkout a workbook
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function checkout($uid = null) {
		if ($this->_wbID )
		{
			// Make sure we have a user id to checkout the article with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$cattable = & $this->getTable();
			if(!$cattable->checkout($uid, $this->_wbID)) {
				$this->setError('<p>Checkout failed!</p><p>' . $this->_db->getErrorMsg() );
				return false;
			}
			return true;
		}
		return false;
	}


	/**
	 * Method to move workbook up or down
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function move($direction) {
		$row =& $this->getTable();
		if (!$row->load($this->_wbID)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		if (!$row->move( $direction, ' published >= 0 ' )) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		return true;
	}

	/**
	 * Method to publish workbook(s)
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function publish($cid = array(), $publish = 1)
	{
		$user 	=& JFactory::getUser();

		if (count( $cid ))
		{
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__sql2excel_workbooks'
				. ' SET published = '. (int) $publish
				. ' WHERE id IN ( '.$cids.' )';
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}

 	/**
	 * Method to reorder the categories
	 *
	 * @access	public
	 * @return	void
	*/
	function saveorder($cid = array(), $order) {
		$row 	=& $this->getTable();
		$total	= count( $cid );

		// update ordering values
		for( $i=0; $i < $total; $i++ )
		{
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					JError::raiseError(500, $db->getErrorMsg() );
				}
			}
		}
		$row->reorder( );
	}

 	/**
	 * Method to store a record
	 *
	 * @access	public
	 * @return	boolean	True on success
	*/
	function store($data)
	{	
			
		$row =& $this->getTable();

		// Bind the form fields to the #__sql2excel_workbooks table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Make sure the record is valid
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Store the web link table to the database
		if (!$row->store()) {
			$this->setError( $row->getErrorMsg() );
			return false;
		} 
		
		return $row->id;
	}
	

 	/**
	 * Method to store worksheets for a workbook
	 *
	 * @access	public
	 * @return	boolean	True on success
	*/
	function storeWS($wbID, $worksheets)
	{
		// Delete previous worksheets
		$query = "DELETE FROM #__sql2excel_worksheet2book " .
			 " WHERE wb_id=" . $wbID;
		$this->_db->setQuery( $query );
		if ( $this->_db->query() ) {
				
			// Add the new worksheets
			$wsArr = explode(',',$worksheets);
			$i=0;
			foreach ( $wsArr  as $wsID ) {
				if ( $wsID > 0 ) {
					$query = "INSERT INTO #__sql2excel_worksheet2book (`wb_id`,`ws_id`,`ordering`) VALUES (" . $wbID . "," . $wsID . "," . $i . ")";
					$this->_db->setQuery( $query );
					$res = $this->_db->query();
					$i++;
				}
			}
			return $res;
		} else {
			return false;
		}
	}
	

	/**
	 * Method to update item access
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function accessmenu($id, $access)
	{
		global $mainframe;
		$row =& $this->getTable();
		$row->load($id);
		$row->id = $id;
		$row->access = $access;
		if ( !$row->check() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		if ( !$row->store() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		return true;
	}


	/**
	 * Method to delete record(s)
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function delete()
	{
		$cids = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		$row =& $this->getTable();

		if (count( $cids )) {
			foreach($cids as $cid) {
				if (!$row->delete( $cid )) {
					$this->setError( $row->getErrorMsg() );
					return false;
				}
			}
		}
		return true;
	}

	/**
	 * Method to retrieve current workbook record
	 *
	 * @access	Private
	 * @return	boolean	True on success
	 */
	function _getData() {
		if (empty($this->_wbData)) {		
			$query = 'SELECT p.* '.	
					' FROM #__sql2excel_workbooks' .
					' WHERE id = ' . (int) $this->_wbID;
			$this->_db->setQuery($query);
			$this->_wbData = $this->_db->loadObject();
			return (boolean) $this->_wbData;
		}
		return true;
	}
	

	/**
	 * Method to export workbook(s) to XML
	 *
	 * @access	public
	 * @return	XML filename if success, false otherwise
	 */
	function exportXML($cid = array())
	{
		
		if (count( $cid ))
		{
			JArrayHelper::toInteger($cid);

			$config =& JFactory::getConfig();
			$tmpPath = $config->getValue( 'config.tmp_path' );
			$xmlFN = $tmpPath . DS. 'sql2excel.xml';
			$file= fopen($xmlFN, "w");
			
			if ( $file ) {
				$sql2excelVer = Sql2excelControlPanel::getVersion('?');
				$wbcnt=1;
				$_xml ="<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\r\n";				
 				$_xml .="<workbooks>\r\n";
 				$_xml .="\t<component>SQL 2 Excel</component>\r\n";
 				$_xml .="\t<version>" . $sql2excelVer . "</version>\r\n";
 				
				foreach ( $cid as $wb_id ) {
					$_xml .="\t<workbook_" . $wbcnt . ">\r\n";
					$query = 'SELECT * FROM #__sql2excel_workbooks WHERE ID=' . $wb_id;
					$this->_db->setQuery( $query );
					$wb = $this->_db->loadObject();
					$colNames = array_keys(get_object_vars($wb));
					foreach ( $colNames as $col ) {
						if ( 	$col != 'id' && 
							$col != 'published' &&
							$col != 'checked_out' &&
							$col != 'checked_out_time' &&
							$col != 'created' &&
							$col != 'access' &&
							$col != 'ordering' &&
							$col != 'count' &&
							$col != 'section' &&
							$col != 'category'
						   ) {
						   	if ( is_numeric($wb->$col) ) {
						   		$_xml .= "\t\t<" . $col . ">" . $wb->$col . "</" . $col . ">\r\n";
						   	} else {
						   		$colVal = str_replace( "\r\n", "@~@", $wb->$col );
								$colVal = str_replace("\n", "@~@", $colVal);
								if ( $colVal == 'Array' ) { $colVal = ''; }
						   		$_xml .= "\t\t<" . $col . "><![CDATA[" . $colVal . "]]></" . $col . ">\r\n";
						   	}
						   }
					}
					
					// Include Worksheets
					$query = 'SELECT a.* ' .
						 'FROM #__sql2excel_worksheets a,  #__sql2excel_worksheet2book b ' .
						 'WHERE b.wb_id=' . $wb_id . ' AND b.ws_id=a.id ' . 
						 'ORDER BY b.ordering';
					$this->_db->setQuery( $query );
					$wsheets = $this->_db->loadObjectList();
					$i=1;
					foreach ( $wsheets as $ws ) {
						$_xml .= "\t\t<worksheet_" . $i . ">\r\n";
						
						$colNames = array_keys(get_object_vars($ws));
						foreach ( $colNames as $col ) {
							if ( 	$col != 'id' && 
								$col != 'published' &&
								$col != 'checked_out' &&
								$col != 'checked_out_time' &&
								$col != 'created' &&
								$col != 'access' &&
								$col != 'ordering' &&
								$col != 'count' &&
								$col != 'database' &&
								$col != 'ws_password'
						   	) {
						   		if ( is_numeric($ws->$col) ) {
						   			$_xml .= "\t\t\t<" . $col . ">" . $ws->$col . "</" . $col . ">\r\n";
						   		} else {
									$colVal = str_replace( "\r\n", "@~@", $ws->$col );
									$colVal = str_replace("\n", "@~@", $colVal);	
									if ( $colVal == 'Array' ) { $colVal = ''; }
						   			$_xml .= "\t\t\t<" . $col . "><![CDATA[" . $colVal . "]]></" . $col . ">\r\n";
						   		}						   	
						   	}
							
						}
						$_xml .= "\t\t</worksheet_" . $i . ">\r\n";
						$i++;
					}
					$_xml .="\t</workbook_" . $wbcnt . ">\r\n";
					$wbcnt++;
				}
				$_xml .="</workbooks>\r\n";
				fwrite($file, $_xml);
				fclose($file);

				// Feed XML file to browser
				header ("Content-type: octet/stream");
				header ("Content-disposition: attachment; filename=sql2excelwb.xml");
				header ("Content-Length: ".filesize($xmlFN));
				readfile($xmlFN);	
				
				return true;
				
			} else {
				return false;
			}

		}
		return false;
	}		

}