<?php
/*
 * @package Joomla 1.5
 * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
 *
 * @component SQL 2 Excel Component
 * @copyright Copyright (C) Joomla-R-Us, joomla-r-us.com
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

require_once(JPATH_SITE.DS.'components'.DS.'com_sql2excel'.DS.'helpers'.DS.'parms.php');


class Sql2excelModelSqlexcelworksheet extends JModel
{
	var $_wsID;
	var $_wsData;

	/**
	 * Constructor that retrieves the ID from the request
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	function setId($id)
	{
		// Set id and wipe data
		$this->_wsID		= $id;
		$this->_wsData	= null;
	}

	/**
	 * Method to get list of Sections
	 * @return select list (html)
	 */
	function getSectionOptions($selected)
	{
		// Get list of sections
		$db	= & JFactory::getDBO();		
		$query = ' SELECT ID AS value, TITLE AS text ' .
			 ' FROM #__sql2excel_sections ' .
			 ' ORDER BY TITLE';
		$this->_db->setQuery( $query );
		$mysections[] = JHTML::_('select.option', '0', '- '.JText::_('Please Select').' -');
		$sections = array_merge($mysections, $db->loadObjectList());
		$sectionsOpt = JHTML::_( 'select.genericlist', 
					 $sections, 
					 'section',  
					 'class="inputbox" size="1"' , 
					 'value', 
					 'text',
					 $selected );
		return $sectionsOpt;
	}

	/**
	 * Method to get list of available colors
	 * @return select list (html)
	 */
	function getExcelColors($name, $selected)
	{
		// Supported colors for Excel Writer
		$mycolors[] = JHTML::_('select.option', 'none', 'None');
		$mycolors[] = JHTML::_('select.option', 'aqua', 'Aqua');
		$mycolors[] = JHTML::_('select.option', 'black', 'Black');
		$mycolors[] = JHTML::_('select.option', 'blue', 'Blue');
		$mycolors[] = JHTML::_('select.option', 'brown', 'Brown');
		$mycolors[] = JHTML::_('select.option', 'cyan', 'Cyan');
		$mycolors[] = JHTML::_('select.option', 'grey', 'Grey');
		$mycolors[] = JHTML::_('select.option', 'lime', 'Lime');
		$mycolors[] = JHTML::_('select.option', 'magenta', 'Magenta');
		$mycolors[] = JHTML::_('select.option', 'navy', 'Navy');
		$mycolors[] = JHTML::_('select.option', 'orange', 'Orange');
		$mycolors[] = JHTML::_('select.option', 'purple', 'Purple');
		$mycolors[] = JHTML::_('select.option', 'red', 'Red');
		$mycolors[] = JHTML::_('select.option', 'silver', 'Silver');
		$mycolors[] = JHTML::_('select.option', 'white', 'White');
		$mycolors[] = JHTML::_('select.option', 'yellow', 'Yellow');

		$colorsOpt = JHTML::_( 'select.genericlist', 
					 $mycolors, 
					 $name,  
					 'class="inputbox" size="1"' , 
					 'value', 
					 'text',
					 $selected );
		return $colorsOpt;
	}

	/**
	 * Method to get list of available colors
	 * @return select list (html)
	 */
	function getExcelTextSizes($name, $selected)
	{
		// Supported colors for Excel Writer
		$mysizes[] = JHTML::_('select.option', '6', '6');
		$mysizes[] = JHTML::_('select.option', '7', '7');
		$mysizes[] = JHTML::_('select.option', '8', '8');
		$mysizes[] = JHTML::_('select.option', '10', '10');
		$mysizes[] = JHTML::_('select.option', '12', '12');
		$mysizes[] = JHTML::_('select.option', '14', '14');
		$mysizes[] = JHTML::_('select.option', '16', '16');
		$mysizes[] = JHTML::_('select.option', '18', '18');
		$mysizes[] = JHTML::_('select.option', '20', '20');
		$mysizes[] = JHTML::_('select.option', '22', '22');
		$mysizes[] = JHTML::_('select.option', '24', '24');

		$colorsOpt = JHTML::_( 'select.genericlist', 
					 $mysizes, 
					 $name,  
					 'class="inputbox" size="1"' , 
					 'value', 
					 'text',
					 $selected );
		return $colorsOpt;
	}


	/**
	 * Method to get list of Worksheet Preview Formula Options
	 * @return select list (html)
	 */
	function getFormulaOptions($name, $selected)
	{
		$mytypes[] = JHTML::_('select.option', 'Global', JText::_( 'Use Global'));
		$mytypes[] = JHTML::_('select.option', 'Show',   JText::_( 'Show Full Formula Syntax'));
		$mytypes[] = JHTML::_('select.option', 'Label',  JText::_( 'Show #FORMULA Label'));
		$mytypes[] = JHTML::_('select.option', 'Hide',   JText::_( 'No'));
		$typesOpt = JHTML::_( 'select.genericlist', 
					 $mytypes, 
					 $name,  
					 'class="inputbox" size="1"', 
					 'value', 
					 'text',
					 $selected );
		return $typesOpt;
	}
	
	
	/**
	 * Method to get data
	 * @return object with data
	 */
	function &getData()
	{

		// Load the data
		if (empty( $this->_wsData )) {
			$query = ' SELECT * FROM #__sql2excel_worksheets ' .
				 ' WHERE id = '.$this->_wsID;
			$this->_db->setQuery( $query );
			$this->_wsData = $this->_db->loadObject();
		}
		if (!$this->_wsData) {
			$sql2excel = new stdClass();
			$sql2excel->id			= 0;
			$sql2excel->title		= null;
			$sql2excel->sheetname		= null;
			$sql2excel->published		= 1;
			$sql2excel->checked_out		= 0;
			$sql2excel->checked_out_time	= null;	
			$sql2excel->created		= null;	
			$sql2excel->access		= 0;
			$sql2excel->header		= null;
			$sql2excel->header_parms	= '';
			$sql2excel->heading_bg_col	= 'silver';
			$sql2excel->heading_text_col	= null;
			$sql2excel->heading_text_size	= 10;
			$sql2excel->colwidths		= null;
			$sql2excel->data_parms		= '';
			$sql2excel->footer		= null;	
			$sql2excel->footer_parms	= '';
			$sql2excel->count		= 0;
			$sql2excel->include_no_records	= 1;
			$sql2excel->error_norecords	= null;
			$sql2excel->query		= null;
			$sql2excel->ordering		= 0;
			$sql2excel->formulas		= null;
			$sql2excel->preview_rows	= null;
			$sql2excel->preview_formulas	= null;
			$sql2excel->preview_hidecols	= null;	
			$sql2excel->print_parms		= '0.75,0.75,1.0,1.0,0,0,0,0,0';				
			$this->_wsData		= $sql2excel;
		}
		return $this->_wsData;
	}
	  
	
	/**
	 * Method to check if a worksheet is checked out or not
	 *
	 * @access	public
	 * @return	boolean	True if it is checked out
	 */
	function isCheckedOut( $uid=0 ) {
		if ($this->_loadData()) {
			if ($uid) {
				return ($this->_wsData->checked_out && $this->_wsData->checked_out != $uid);
			} else {
				return $this->_wsData->checked_out;
			}
		}
	}

	/**
	 * Method to checkin a worksheet
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function checkin() {
		if ($this->_wsID ) {
			$cattable = & $this->getTable();
			if(! $cattable->checkin($this->_wsID)) {
				$this->setError('<p>Checkin failed!</p><p>' . $this->_db->getErrorMsg());
				return false;
			}
		}
		return false;
	}

	/**
	 * Method to checkout a worksheet
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function checkout($uid = null) {
		if ($this->_wsID )
		{
			// Make sure we have a user id to checkout the article with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$cattable = & $this->getTable();
			if(!$cattable->checkout($uid, $this->_wsID)) {
				$this->setError('<p>Checkout failed!</p><p>' . $this->_db->getErrorMsg() );
				return false;
			}
			return true;
		}
		return false;
	}


	/**
	 * Method to move worksheet up or down
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function move($direction) {
		$row =& $this->getTable();
		if (!$row->load($this->_wsID)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		if (!$row->move( $direction, ' published >= 0 ' )) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		return true;
	}
	

	/**
	 * Method to get list of font types
	 * @return select list (html)
	 */
	function getFontTypes($name, $selected)
	{
		$myopt[] 	= JHTML::_('select.option', 'Arial',   'Arial');
		$myopt[] 	= JHTML::_('select.option', 'Comic Sans MS', 'Comic Sans MS');
		$myopt[] 	= JHTML::_('select.option', 'Courier', 'Courier');
		$myopt[] 	= JHTML::_('select.option', 'Courier New', 'Courier New');
		$myopt[] 	= JHTML::_('select.option', 'Georgia', 'Georgia');
		$myopt[] 	= JHTML::_('select.option', 'Tahoma', 'Tahoma');
		$myopt[] 	= JHTML::_('select.option', 'Times New Roman', 'Times New Roman');
		$myopt[] 	= JHTML::_('select.option', 'Trebuchet MS', 'Trebuchet MS');
		$myopt[] 	= JHTML::_('select.option', 'Verdana', 'Verdana');		
		$myopts 	= JHTML::_( 'select.genericlist', 
					 	$myopt, 
					 	$name,  
					 	'class="inputbox" size="1"' , 
					 	'value', 
					 	'text',
					 	$selected );	
	 	return $myopts;	 	
	}
	

	/**
	 * Method to get list of font weights
	 * @return select list (html)
	 */
	function getFontWeights($name, $selected)
	{
		$myweight[] 	= JHTML::_('select.option', 'normal', 'Normal');
		$myweight[] 	= JHTML::_('select.option', 'bold', 'Bold');
		$weightOpt 	= JHTML::_( 'select.genericlist', 
					 	$myweight, 
					 	$name,  
					 	'class="inputbox" size="1"' , 
					 	'value', 
					 	'text',
					 	$selected );	
	 	return $weightOpt;
	}
	
	function getHeaderParms($parmStr)
	{
	
		if ( $parmStr == '' ) {
			$parmStr = 'Arial,10,normal,black,none';
		}
		
		$parmObj = new stdClass();
		$parms = explode(',', $parmStr);
		if ( sizeof($parms) >= 5 ) {
			$parmObj->header_font_family=$parms[0];
			$parmObj->header_font_size=$parms[1];
			$parmObj->header_font_weight=$parms[2];
			$parmObj->header_font_color=$parms[3];
			$parmObj->header_font_bgcolor=$parms[4];
		}
		return $parmObj;
	}


	function getDataParms($parmStr)
	{
		if ( $parmStr == '' ) {
			$parmStr = 'Arial,10,normal,black,None,silver,1,27,1';
		}		
		$parmObj = new stdClass();
		$parms = explode(',', $parmStr);
		if ( sizeof($parms) >= 9 ) {
			$parmObj->data_font_family=$parms[0];
			$parmObj->data_font_size=$parms[1];
			$parmObj->data_font_weight=$parms[2];
			$parmObj->data_font_color=$parms[3];
			$parmObj->data_nr_bgcolors=$parms[4];
			$parmObj->data_bgcolor_1=$parms[5];
			$parmObj->data_bgcolor_1_cnt=$parms[6];
			$parmObj->data_bgcolor_2=$parms[7];
			$parmObj->data_bgcolor_2_cnt=$parms[8];				
		}
		return $parmObj;
	}


	function getPrintParms($parmStr)
	{
	
		if ( $parmStr == '' ) {
			$parmStr = ',,,,1,1,0,0';
		}		
		$parmObj = new stdClass();
		$parms = explode(',', $parmStr);

		if ( sizeof($parms) >= 4 ) {
			$parmObj->print_left_margin=$parms[0];
			$parmObj->print_right_margin=$parms[1];
			$parmObj->print_top_margin=$parms[2];
			$parmObj->print_bot_margin=$parms[3];			
		}
		return $parmObj;
	}
	

	/**
	 * Method to get Backgroun Color Options
	 * @return select list (html)
	 */
	function getDataBGcolOptions($name, $selected, $onChange)
	{
		$mytypes[] = JHTML::_('select.option', 'None', JText::_( 'None'));
		$mytypes[] = JHTML::_('select.option', '1',   JText::_( '1 color'));
		$mytypes[] = JHTML::_('select.option', '2',  JText::_( '2 alternating colors'));
		$typesOpt = JHTML::_( 'select.genericlist', 
					 $mytypes, 
					 $name,  
					 'class="inputbox" size="1" ' . $onChange, 
					 'value', 
					 'text',
					 $selected );
		return $typesOpt;
	}
	
	
	/**
	 * Method to publish worksheet(s)
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function publish($cid = array(), $publish = 1)
	{
		$user 	=& JFactory::getUser();

		if (count( $cid ))
		{
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__sql2excel_worksheets'
				. ' SET published = '. (int) $publish
				. ' WHERE id IN ( '.$cids.' )';
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}

 	/**
	 * Method to reorder the categories
	 *
	 * @access	public
	 * @return	void
	*/
	function saveorder($cid = array(), $order) {
		$row 	=& $this->getTable();
		$total	= count( $cid );

		// update ordering values
		for( $i=0; $i < $total; $i++ )
		{
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					JError::raiseError(500, $db->getErrorMsg() );
				}
			}
		}
		$row->reorder( );
	}

 	/**
	 * Method to store a record
	 *
	 * @access	public
	 * @return	boolean	True on success
	*/
	function store($data)
	{	
		$row =& $this->getTable();

		// Bind the form fields to the #__sql2excel_categories table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Make sure the record is valid
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Store the web link table to the database
		if (!$row->store()) {
			$this->setError( $row->getErrorMsg() );
			return false;
		}

		return $row->id;
	}

	/**
	 * Method to update item access
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function accessmenu($id, $access)
	{
		global $mainframe;
		$row =& $this->getTable();
		$row->load($id);
		$row->id = $id;
		$row->access = $access;
		if ( !$row->check() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		if ( !$row->store() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		return true;
	}


	/**
	 * Method to delete record(s)
	 *
	 * @access	public
	 * @return	boolean	True on success
	 */
	function delete()
	{
		$cids = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		$row =& $this->getTable();

		if (count( $cids )) {
			foreach($cids as $cid) {
				if (!$row->delete( $cid )) {
					$this->setError( $row->getErrorMsg() );
					return false;
				} else {
					// Remove from Worksheet mapping table
					$query = 'DELETE FROM #__sql2excel_worksheet2book WHERE ws_id=' . $cid;
					$this->_db->setQuery( $query );
					$this->_db->query();
				}
			}
		}
		return true;
	}
	

	/**
	 * Method to retrieve SQL Help Tabs
	 *
	 * @access	public
	 * @return	Help Tabs HTML snippet
	 */
	function getHelpTabs($params)
	{

		//$showhelpTabs = $params->get( 'showsqlhelptabs', '1' );
		$showhelpTabs = Sql2excelParms::get($params,'showsqlhelptabs', '1');
		
		if ( $showhelpTabs ) {
			$proLink = 'Only in <a href="http://Joomla-R-Us.com/sql2excelpro" target="_NEW">SQL 2 Excel Pro</a>';
			//$helpLinks = $params->get( 'sqlhelplinks', '<span width=200><center><a href="http://dev.mysql.com/doc/refman/5.0/en/sql-syntax.html" target="_NEW">MySQL SQL Syntax</a></center><span width=200><center><a href="http://Joomla-R-Us.com/sql2excelsvarref" target="_NEW">Variable Substitution Reference</a></center></span><span width=200><center><a href="http://Joomla-R-Us.com/sql2excelformulas" target="_NEW">Formulas</a></center></span>' );
			$helpLinks = Sql2excelParms::get($params,'sqlhelplinks','<span width=200><center><a href="http://dev.mysql.com/doc/refman/5.0/en/sql-syntax.html" target="_NEW">MySQL SQL Syntax</a></center><span width=200><center><a href="http://Joomla-R-Us.com/sql2excelsvarref" target="_NEW">Variable Substitution Reference</a></center></span><span width=200><center><a href="http://Joomla-R-Us.com/sql2excelformulas" target="_NEW">Formulas</a></center></span>' );
			
			return '<div id="demo" class="demolayout">
				<ul id="demo-nav" class="demolayout">
					<li><a href="#tab1"><small>Help</small></a></li>
					<li><a href="#tab2"><small>Tables</small></a></li>
					<li><a href="#tab3"><small>Syntax / Errors</small></a></li>
					<li><a href="#tab4"><small>Explain</small></a></li>
				</ul>

				<div class="tabs-container">

					<div class="tab" id="tab1">
					<p class="km-def">' . $helpLinks . '</p>
					</div>

					<div class="tab" id="tab2">
					<p class="km-def">List of available tables. ' . $proLink . '</p>
					</div>

					<div class="tab" id="tab3">
					<p class="km-def">Ajax powered, on-the-fly Syntax / Error check. ' . $proLink . '</p>
					</div>

					<div class="tab" id="tab4">
					<p class="km-def">Explain SQL query. Helps fine tuning your query. ' . $proLink . '</p>
					</div>
				</div>
			</div>

			<script type="text/javascript">

			function customfunction(tabnumber) {

			}

			var tabber1 = new Yetii({
			id: \'demo\',
			callback: customfunction,
			persist: true
			});
			</script>';
		} else {
			return '';
		}
	}


	

	/**
	 * Method to retrieve current worksheet record
	 *
	 * @access	Private
	 * @return	boolean	True on success
	 */
	function _getData() {
		if (empty($this->_wsData)) {		
			$query = 'SELECT p.* '.	
					' FROM #__sql2excel_categories' .
					' WHERE id = ' . (int) $this->_wsID;
			$this->_db->setQuery($query);
			$this->_wsData = $this->_db->loadObject();
			return (boolean) $this->_wsData;
		}
		return true;
	}
	


	

}
