<?php
/**
 * This file contains the routines that display the administrator
 *  screens for the eWeather component.
 *
 * This file is part of eWeather.
 *
 *   eWeather is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   eWeather is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with eWeather.  If not, see <a href="http://www.gnu.org/licenses/">
 *   http://www.gnu.org/licenses/</a>.
 *
 * <b>Modifications:</b><br/>
 * aangepast door Mart Dirks<br/>
 * converted to Joomla! 1.5.x by Bob Lavey
 *
 * @version $Id: eweather.main.php 234 2009-06-22 17:04:29Z rjlavey $
 * @package eWeather
 * @subpackage eWeather
 * @copyright Copyright (c) 2000 - 2006 MamboBaer.de (Harald Baer),
 *            2009 Bob Lavey<br/>
 * @license http://www.gnu.org/licenses/gpl.txt GNU/GPL
 * @toto General clean up, convert to classes.
 */

/* ensure this file is being called by Joomla! */
defined('_JEXEC') or die('Direct Access to this location is not allowed.');

require_once( JPATH_SITE.DS.'/includes/domit/xml_domit_include.php' );
require_once(JPATH_ADMINISTRATOR.DS."components/com_eweather/eweather.config.php");

function parseWeather($cfg, $weatherLocation)
{
	$weatherClass = & new weather_global();
	$database = &JFactory::getDBO();
	$defaultLocationID = "";

	if ($weatherLocation != null)
	{
		$defaultLocationID = $weatherLocation;
	}
	
	//
	// first check for a locid associated with the user ID
	//
	if ($defaultLocationID == "")
	{
		$user =& JFactory::getUser();
		$userId = $user->get('id');
	 
		if ($userId != 0)
		{
			$database -> setQuery("SELECT * FROM #__eweather_profiles WHERE `uid` = '".$userId."'");
			$userProfiles = $database -> loadObjectList();
			if (count($userProfiles) != 0)
			{
				$defaultLocationID = $userProfiles[0]->locid;
			}
		}
	}

	//
	// if no valid user ID or no valid locid,
	//  check for a cookie
	//
	if (($defaultLocationID == "") AND isset($_COOKIE["defaultWeatherLocation"]))
	{
		$defaultLocationID = $_COOKIE["defaultWeatherLocation"];
	}

	//
	// default to the site configuration's default location
	//
	if ($defaultLocationID == "")
	{
		$defaultLocationID = $cfg->GetDefaultLocation();
	}

	//
	// retrieve and parse the Current Conditions
	//  and the Daily Forecasts
	//
	$xmlDoc = RetrieveDailyForecasts($cfg, $defaultLocationID, $weatherClass);
	if ($weatherClass->e_error == "")
	{
		ParseWeatherChannelData($cfg, $xmlDoc, $weatherClass);
	}
	if ($weatherClass->e_error == "")
	{
		$xmlDoc = RetrieveCurrentConditions($cfg, $defaultLocationID, $weatherClass);
	}
	if ($weatherClass->e_error == "")
	{
		ParseWeatherChannelData($cfg, $xmlDoc, $weatherClass);
	}
	 
	return $weatherClass;
}

function RetrieveDailyForecasts($cfg, $locationID, &$weatherClass)
{
	$database = &JFactory::getDBO();

	//
	// set up the XML document
	//
	$xmlDoc =& new DOMIT_Document();
	$xmlDoc->resolveErrors(true);
	if ($cfg->GetUseProxy() == "1")
	{
		$xmlDoc->setProxyConnection($cfg->GetProxyHost(), '/', $cfg->GetProxyPort());
		if ($cfg->GetUseProxyAuth() == "1")
		{
			$xmlDoc->setProxyAuthorization($cfg->GetProxyAuthUser(), $cfg->GetProxyAuthPwd());
		}
	}
	 
	$weather_url = "http://xoap.weather.com/weather/local/".$locationID."?cc=*&link=xoap&prod=xoap&dayf=".$cfg->GetForecastDays()."&unit=".$cfg->GetUnitsForWeatherChannel()."&par=".$cfg->GetPartnerID()."&key=".$cfg->GetPartnerKey();
	 
	//
	// try to find the cached data in the database
	//
	$sql = "SELECT * FROM #__eweather_cache WHERE `locid` = '".$locationID."' AND `dataType` = 'dayf' AND `units` =  '".$cfg->GetUnitsForWeatherChannel()."'";
	$database -> setQuery($sql);
	$rows = $database -> loadObjectList();
	$cacheCount = count($rows);

	//
	// cached data was found
	//
	if ($cacheCount != 0)
	{
		$cacheID = $rows[0]->id;
		$cacheTime = time() - 12600; /* 210 minutes */;

		//
		// cached data was found, and it is still valid
		//
		if ($rows[0]->lastupdate > $cacheTime)
		{
			$xmlDoc->parseXML($rows[0]->feed, true);
		}
		//
		// cached data was found, but it needs to be refreshed
		//
		else
		{
			$success = $xmlDoc->loadXML($weather_url, true);
			if ($success)
			{
				if ($xmlDoc->documentElement->getTagName() == 'weather')
				{
					$newFeed = $xmlDoc->toString(false);
					$sql = "UPDATE #__eweather_cache SET `lastupdate` = '".time()."',`feed` = '$newFeed' WHERE `id` = '$cacheID'";
					$database -> setQuery($sql);
					$database -> query();
				}
			}
			else
			{
				$weatherClass->e_error = "Error number ".$xmlDoc->getErrorCode().": ".$xmlDoc->getErrorString()." while retrieving Daily Forecasts";
			}
		}
	}
	//
	// cached data was not found
	//
	else
	{
		$success = $xmlDoc->loadXML($weather_url, true);
		if ($success)
		{
			if ($xmlDoc->documentElement->getTagName() == 'weather')
			{
				$newFeed = $xmlDoc->toString(false);
				$sql = "INSERT INTO #__eweather_cache ( `id` , `lastupdate` , `locid` , `dataType` , `units`, `feed` ) VALUES ('','".time()."', '$locationID', 'dayf', '".$cfg->GetUnitsForWeatherChannel()."', '$newFeed');";
				$database -> setQuery($sql);
				$database -> query();
			}
		}
		else
		{
			$weatherClass->e_error = "Error number ".$xmlDoc->getErrorCode().": ".$xmlDoc->getErrorString()." while retrieving Daily Forecasts";
		}
	}

	return $xmlDoc;
}

function RetrieveCurrentConditions($cfg, $locationID, &$weatherClass)
{
	$database = &JFactory::getDBO();

	//
	// set up the XML document
	//
	$xmlDoc =& new DOMIT_Document();
	$xmlDoc->resolveErrors(true);
	if ($cfg->GetUseProxy() == "1")
	{
		$xmlDoc->setProxyConnection($cfg->GetProxyHost(), '/', $cfg->GetProxyPort());
		if ($cfg->GetUseProxyAuth() == "1")
		{
			$xmlDoc->setProxyAuthorization($cfg->GetProxyAuthUser(), $cfg->GetProxyAuthPwd());
		}
	}
	 
	$weather_url = "http://xoap.weather.com/weather/local/".$locationID."?cc=*&link=xoap&prod=xoap&unit=".$cfg->GetUnitsForWeatherChannel()."&par=".$cfg->GetPartnerID()."&key=".$cfg->GetPartnerKey();
	 
	//
	// try to find the cached data in the database
	//
	$sql = "SELECT * FROM #__eweather_cache WHERE `locid` = '".$locationID."' AND `dataType` = 'cc' AND `units` =  '".$cfg->GetUnitsForWeatherChannel()."'";
	$database -> setQuery($sql);
	$rows = $database -> loadObjectList();
	$cacheCount = count($rows);

	//
	// cached data was found
	//
	if ($cacheCount != 0)
	{
		$cacheID = $rows[0]->id;
		$cacheTime = time() - $cfg->GetCacheTime();

		//
		// cached data was found, and it is still valid
		//
		if ($rows[0]->lastupdate > $cacheTime)
		{
			$xmlDoc->parseXML($rows[0]->feed, true);
		}
		//
		// cached data was found, but it needs to be refreshed
		//
		else
		{
			$success = $xmlDoc->loadXML($weather_url, true);
			if ($success)
			{
				if ($xmlDoc->documentElement->getTagName() == 'weather')
				{
					$newFeed = $xmlDoc->toString(false);
					$sql = "UPDATE #__eweather_cache SET `lastupdate` = '".time()."',`feed` = '$newFeed' WHERE `id` = '$cacheID'";
					$database -> setQuery($sql);
					$database -> query();
				}
			}
			else
			{
				$weatherClass->e_error = "Error number ".$xmlDoc->getErrorCode().": ".$xmlDoc->getErrorString()." while retrieving Current Conditions";
			}
		}
	}
	//
	// cached data was not found
	//
	else
	{
		$success = $xmlDoc->loadXML($weather_url, true);
		if ($success)
		{
			if ($xmlDoc->documentElement->getTagName() == 'weather')
			{
				$newFeed = $xmlDoc->toString(false);
				$sql = "INSERT INTO #__eweather_cache ( `id` , `lastupdate` , `locid` , `dataType` , `units` , `feed` ) VALUES ('', '".time()."', '$locationID', 'cc', '".$cfg->GetUnitsForWeatherChannel()."', '$newFeed');";
				$database -> setQuery($sql);
				$database -> query();
			}
		}
		else
		{
			$weatherClass->e_error = "Error number ".$xmlDoc->getErrorCode().": ".$xmlDoc->getErrorString()." while retrieving Current Conditions";
		}
	}

	return $xmlDoc;
}

function ParseWeatherChannelData($cfg, $xmlDoc, &$weatherClass)
{
	$element = $xmlDoc->documentElement;
	$numChannels = count($xmlDoc->documentElement->childNodes);
	$weatherClass->n_channels = count($xmlDoc->documentElement->childNodes);

	if ($element->getTagName() == 'weather')
	{
		$nodeCount = count($xmlDoc->documentElement->childNodes);
		for ($i = 0; $i < $nodeCount; $i++)
		{
			$currentNode =& $xmlDoc->documentElement->childNodes[$i];
			switch($currentNode->nodeName)
			{
				case 'head':
					$headNode = $currentNode;
					$headNodeCount = count($headNode->childNodes);
					for ($x = 0; $x < $headNodeCount; $x++)
					{
						if ($headNode->childNodes[$x]->nodeName == "ut") $weatherClass->h_temp = $headNode->childNodes[$x]->firstChild->nodeValue;
						if ($headNode->childNodes[$x]->nodeName == "ud") $weatherClass->h_distance = $headNode->childNodes[$x]->firstChild->nodeValue;
						if ($headNode->childNodes[$x]->nodeName == "us") $weatherClass->h_speed = $headNode->childNodes[$x]->firstChild->nodeValue;
						if ($headNode->childNodes[$x]->nodeName == "ur") $weatherClass->h_precipitation = $headNode->childNodes[$x]->firstChild->nodeValue;
						if ($headNode->childNodes[$x]->nodeName == "up") $weatherClass->h_pressure = $headNode->childNodes[$x]->firstChild->nodeValue;
					}
					break;
				case 'loc':
					$locNode = $currentNode;
					$weatherClass->loc_code = $locNode->getAttribute('id');
					$locNodeCount = count($locNode->childNodes);
					for ($x = 0; $x < $locNodeCount; $x++)
					{
						if ($locNode->childNodes[$x]->nodeName == "dnam") $weatherClass->loc_city = $locNode->childNodes[$x]->firstChild->nodeValue;
						if ($locNode->childNodes[$x]->nodeName == "tm") $weatherClass->loc_localtime = $locNode->childNodes[$x]->firstChild->nodeValue;
						if ($locNode->childNodes[$x]->nodeName == "lat") $weatherClass->loc_latitude = $locNode->childNodes[$x]->firstChild->nodeValue;
						if ($locNode->childNodes[$x]->nodeName == "lon") $weatherClass->loc_longitude = $locNode->childNodes[$x]->firstChild->nodeValue;
						if ($locNode->childNodes[$x]->nodeName == "sunr")
						{
							$weatherClass->loc_sunrise = strftime($cfg->GetTimeFormat(), strtotime($locNode->childNodes[$x]->firstChild->nodeValue));
						}
						if ($locNode->childNodes[$x]->nodeName == "suns"){
							$weatherClass->loc_sunset = strftime($cfg->GetTimeFormat(), strtotime($locNode->childNodes[$x]->firstChild->nodeValue));
						}
						if ($locNode->childNodes[$x]->nodeName == "zone") $weatherClass->loc_timezone = $locNode->childNodes[$x]->firstChild->nodeValue;
					}
					break;
				case 'cc':
					$ccNode = $currentNode;
					$ccNodeCount = count($ccNode->childNodes);
					for ($x = 0; $x < $ccNodeCount; $x++)
					{
						if ($ccNode->childNodes[$x]->nodeName == "bar")
						{
							$ccNodeCount_x = 0;
							$ccNodeCount_x = count($ccNode->childNodes[$x]->childNodes);
							for ($y = 0; $y < $ccNodeCount_x; $y++)
							{
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "r") $weatherClass->cc_barpressure = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "d") $weatherClass->cc_bartext = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
							}
						}
						elseif ($ccNode->childNodes[$x]->nodeName == "uv")
						{
							$ccNodeCount_x = 0;
							$ccNodeCount_x = count($ccNode->childNodes[$x]->childNodes);
							for ($y = 0; $y < $ccNodeCount_x; $y++)
							{
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "i") $weatherClass->cc_uvindex = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "t") $weatherClass->cc_uvtext = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
							}
						}
						elseif ($ccNode->childNodes[$x]->nodeName == "moon")
						{
							$ccNodeCount_x = 0;
							$ccNodeCount_x = count($ccNode->childNodes[$x]->childNodes);
							for ($y = 0; $y < $ccNodeCount_x; $y++)
							{
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "icon") $weatherClass->cc_moonicon = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "t") $weatherClass->cc_moontext = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
							}
						}
						elseif ($ccNode->childNodes[$x]->nodeName == "wind")
						{
							$ccNodeCount_x = 0;
							$ccNodeCount_x = count($ccNode->childNodes[$x]->childNodes);
							for ($y = 0; $y < $ccNodeCount_x; $y++)
							{
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "s") $weatherClass->cc_windspeed = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "gust") $weatherClass->cc_windgust = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "d") $weatherClass->cc_winddirection = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($ccNode->childNodes[$x]->childNodes[$y]->nodeName == "t") $weatherClass->cc_windtext = $ccNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
							}
						}
						else
						{
							if ($ccNode->childNodes[$x]->nodeName == "lsup") {
								$weatherClass->cc_lastupdate = strftime($cfg->GetDateFormatLong(), strtotime(ereg_replace(" Local Time", "", $ccNode->childNodes[$x]->firstChild->nodeValue)));
							}
							if ($ccNode->childNodes[$x]->nodeName == "obst") $weatherClass->cc_observatory = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "tmp") $weatherClass->cc_temp = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "flik") $weatherClass->cc_windchill = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "t") $weatherClass->cc_text = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "icon") $weatherClass->cc_icon = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "hmid") $weatherClass->cc_humidity = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "vis") $weatherClass->cc_visibility = $ccNode->childNodes[$x]->firstChild->nodeValue;
							if ($ccNode->childNodes[$x]->nodeName == "dewp") $weatherClass->cc_dewp = $ccNode->childNodes[$x]->firstChild->nodeValue;
						}
					}
					break;
				case 'dayf':
					$dayfNode = $currentNode;
					$dayfNodeCount = count($dayfNode->childNodes);
					for ($x = 0; $x < $dayfNodeCount; $x++)
					{
						if ($dayfNode->childNodes[$x]->nodeName == "lsup")
						{
							$weatherClass->dayf_lastupdate = strftime ($cfg->GetDateFormatLong(), strtotime (ereg_replace("Local Time", "", $dayfNode->childNodes[$x]->firstChild->nodeValue)));
						}
						if ($dayfNode->childNodes[$x]->nodeName == "day")
						{
							$weatherDayClass =& new weather_day();
							$weatherDayClass->day_num = $dayfNode->childNodes[$x]->getAttribute('d');
							$weatherDayClass->day_weekday = $dayfNode->childNodes[$x]->getAttribute('t');
							$weatherDayClass->day_date = $dayfNode->childNodes[$x]->getAttribute('dt');
							$dayCount = count($dayfNode->childNodes[$x]->childNodes);
							for ($y = 0; $y < $dayCount; $y++)
							{
								if ($dayfNode->childNodes[$x]->childNodes[$y]->nodeName == "hi") $weatherDayClass->day_temp_max = $dayfNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($dayfNode->childNodes[$x]->childNodes[$y]->nodeName == "low") $weatherDayClass->day_temp_min = $dayfNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue;
								if ($dayfNode->childNodes[$x]->childNodes[$y]->nodeName == "sunr")
								{
									$weatherDayClass->day_sunrise = strftime($cfg->GetTimeFormat(), strtotime($dayfNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue));
								}
								if ($dayfNode->childNodes[$x]->childNodes[$y]->nodeName == "suns")
								{
									$weatherDayClass->day_sunset = strftime($cfg->GetTimeFormat(), strtotime($dayfNode->childNodes[$x]->childNodes[$y]->firstChild->nodeValue));
								}
								if ($dayfNode->childNodes[$x]->childNodes[$y]->nodeName == "part")
								{
									$partCount = count($dayfNode->childNodes[$x]->childNodes[$y]->childNodes);
									for ($z = 0; $z < $dayCount; $z++)
									{
										$flag = $dayfNode->childNodes[$x]->childNodes[$y]->getAttribute('p');
										if ($flag == "d")
										{
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "icon") $weatherDayClass->day_d_icon = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "t") $weatherDayClass->day_d_text = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "bt") $weatherDayClass->day_d_windtextd = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "ppcp") $weatherDayClass->day_d_precipitation = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "hmid") $weatherDayClass->day_d_humidity = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "wind")
											{
												$dayWindCount = count($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes);
												for ($v = 0; $v < $dayWindCount; $v++)
												{
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "s") $weatherDayClass->day_d_windspeed = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "gust") $weatherDayClass->day_d_windgust = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "d") $weatherDayClass->day_d_winddirection = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "t") $weatherDayClass->day_d_windtext = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
												}
											}
										}
										else
										{
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "icon") $weatherDayClass->day_n_icon = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "t") $weatherDayClass->day_n_text = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "bt") $weatherDayClass->day_n_windtextd = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "ppcp") $weatherDayClass->day_n_precipitation = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "hmid") $weatherDayClass->day_n_humidity = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->firstChild->nodeValue;
											if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->nodeName == "wind")
											{
												$dayWindCount = count($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes);
												for ($v = 0; $v < $dayWindCount; $v++)
												{
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "s") $weatherDayClass->day_n_windspeed = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "gust") $weatherDayClass->day_n_windgust = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "d") $weatherDayClass->day_n_winddirection = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
													if ($dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->nodeName == "t") $weatherDayClass->day_n_windtext = $dayfNode->childNodes[$x]->childNodes[$y]->childNodes[$z]->childNodes[$v]->firstChild->nodeValue;
												}
											}
										}
									}
								}
							}
							$weatherClass->dayf_forecasts[] = & $weatherDayClass;
						}
					}
					break;
				case 'lnks':
					unset($weatherClass->partnerLinks);
					$lnksNode = $currentNode;
					$lnksNodeCount = count($lnksNode->childNodes);
					for ($x = 0; $x < $lnksNodeCount; $x++)
					{
						if ($lnksNode->childNodes[$x]->nodeName == "link")
						{
							$partnerLink =& new PartnerLink();
							$linkNode = $lnksNode->childNodes[$x];
							$linkNodeCount = count($linkNode->childNodes);
							for ($y = 0; $y < $linkNodeCount; $y++)
							{
								if ($linkNode->childNodes[$y]->nodeName == "l")
								{
									$partnerLink->url = $linkNode->childNodes[$y]->firstChild->nodeValue;
								}
								if ($linkNode->childNodes[$y]->nodeName == "t")
								{
									$partnerLink->text = $linkNode->childNodes[$y]->firstChild->nodeValue;
								}
							}
							$weatherClass->partnerLinks[] = & $partnerLink;
						}
					}
					break;

				default:
					break;
					
			}  // end switch
		} // end for
	} //end if
	elseif ($element->getTagName() == 'error')
	{
		$x_error = $xmlDoc->documentElement->childNodes[0]->firstChild->nodeValue."\n";
		$x_error.="<br>".JText::_('EWEATHER_ERROR_CODE').": ".$xmlDoc->documentElement->childNodes[0]->getAttribute('type')."\n";
		$weatherClass->e_error = $x_error;
	}
	else
	{
		$weatherClass->e_error = JText::_('EWEATHER_UNKNOWN_ERROR');
	}
}
?>