<?php
/*
 * @component SQL 2 Excel Pro Component
 * @copyright Copyright (C) Joomla-R-Us, joomla-r-us.com
 * @license http://www.gnu.org/licenses/gpl-3.0.html GNU/GPLv3
 *
 * Original code by Jan Pavelka (www.phoca.cz) 					
 * Adapted by Joomla-R-Us for SQl 2 Excel Pro
 *
 */
 
 /*
  * @package Joomla 1.5
  * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
  * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
  *
  * @component Phoca Component
  * @copyright Copyright (C) Jan Pavelka www.phoca.cz
  * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport('joomla.application.component.model');

require_once( JPATH_COMPONENT.DS.'helpers'.DS.'query.php' );
require_once( JPATH_COMPONENT.DS.'helpers'.DS.'parms.php' );

class Sql2excelModelCategory extends JModel
{
	var $_document 			= null;
	var $_category 			= null;
	var $_section			= null;
	var $_filename			= null;
	var $_directlink		= 0;
	var $_file_ordering		= null;
	var $_pagination		= null;
	var $_total				= null;

	function __construct() {
		
		global $mainframe;
		parent::__construct();
		
		$config = JFactory::getConfig();		
		
		$paramsC 			= JComponentHelper::getParams('com_sql2excel') ;
		$defaultPagination	= $paramsC->get( 'default_pagination', '20' );
		
		// Get the pagination request variables
		$this->setState('limit', $mainframe->getUserStateFromRequest('com_sql2excel.limit', 'limit', $defaultPagination, 'int'));
		$this->setState('limitstart', JRequest::getVar('limitstart', 0, '', 'int'));

		// In case limit has been changed, adjust limitstart accordingly
		$this->setState('limitstart', ($this->getState('limit') != 0 ? (floor($this->getState('limitstart') / $this->getState('limit')) * $this->getState('limit')) : 0));

		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'ordering'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
		
	}
	
	function getPagination($categoryId, $params) {
		if (empty($this->_pagination)) {
			jimport('joomla.html.pagination');
			$this->_pagination = new Sql2excelPagination( $this->getTotal($categoryId, $params), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}
	
	function getTotal($categoryId, $params) {
		if (empty($this->_total)) {
			$user	=& JFactory::getUser();
			$aid 	= $user->get('aid', 0);	
			$query = $this->_getDocumentListQuery($categoryId, $aid, $params);
			$this->_total = $this->_getListCount($query);
		}
		return $this->_total;
	}

	
	function getDownloadURL($id) {
	        // Link to Workbook directly
	        $url = 'index.php?option=com_sql2excel&controller=download&task=dl&id='.$id;	        
		return array($url,'');	
	}

	function getPreviewURL($id, $preview) {

		$url = '';
		$target = '';		
	        if ( $preview == 'inline' ) {
	        	$url = 'index.php?option=com_sql2excel&controller=preview&task=popup&id='.$id;
	        } elseif ( $preview == 'inlinewt' )  {
	        	$url = 'index.php?option=com_sql2excel&view=pre&id='.$id;
	        } elseif ( $preview == 'popup' )  {
	        	$url = 'index.php?option=com_sql2excel&controller=preview&task=popup&id='.$id;
	        	$target = ' target="_NEW" ';
	        } elseif ( $preview == 'popupwt' )  {
	        	$url = 'index.php?option=com_sql2excel&view=pre&id='.$id;
	        	$target = ' target="_NEW" ';	
	        }	
		return array($url,$target);	
	}

	
	function getDocumentKeywords($workbooks) {
		$keywords = '';
		foreach ($workbooks as $wb ) {
			$keywords .=  $wb->keywords . ' ';
		}
		
		$keywords = trim($keywords);
		if ( $keywords != '' ) {
			$keywords 	= strtolower(str_replace(' ', ',', $keywords));
			$keywordArr 	= explode(',', $keywords);
			$keywordArr 	= array_unique($keywordArr);
			$keywords = implode(',',$keywordArr);			
		}		
		return $keywords;
	}	
	

	function getDocumentList($categoryId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		
		if (empty($this->_document)) {	
			global $mainframe;
			$user 			= &JFactory::getUser();
			$aid 			= $user->get('aid', 0);			
			$query			= $this->_getDocumentListQuery( $categoryId, $aid, $params );
			$this->_document= $this->_getList( $query ,$this->getState('limitstart'), $this->getState('limit'));
			
			if (!empty($this->_document)) {
				$showPreview = Sql2excelParms::get($params,'show_preview_button', 1);
				$previewMode = Sql2excelParms::get($params,'preview_mode', 'popup');
				
				$dlParms = false;
				foreach ($this->_document as $key => $value) {
					$this->_document[$key]->download_url = $this->getDownloadURL($value->id);
					if ( $showPreview ) {
						$this->_document[$key]->preview_url = $this->getPreviewURL($value->id, $previewMode);
					}
				}
			}
			
		}
		return $this->_document;
	}
	
	function _getDocumentListQuery( $categoryId, $aid, $params ) {

		// Filter Sections / Categories ?
		$section_ids_where = $params->get( 'display_sections', '' );
		$section_ids_not_where = $params->get( 'hide_sections', '' );
		$category_ids_where = $params->get( 'display_categories', '' );
		$category_ids_not_where = $params->get( 'hide_categories', '' );

		$wheres[] = ' e.id= '.(int)$categoryId;
 		$query = Sql2excelQuery::getBaseQuery(	"DISTINCT a.*, e.id AS categoryid, e.title AS categorytitle, '' as download_url, '' as preview_url", 
 							$wheres, 
 							'',
 							'',
 							$section_ids_where,
 							$section_ids_not_where,
 							$category_ids_where,
 							$category_ids_not_where);
				
		return $query;
	}
	
	function getCategory($categoryId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		//$wheres[] = " cc.published = 1 ";	
		if (empty($this->_category)) {	
			global $mainframe;
			$user 			= &JFactory::getUser();
			$aid 			= $user->get('aid', 0);			
			$query			= $this->_getCategoryQuery( $categoryId, $aid, $params );
			$this->_category= $this->_getList( $query, 0, 1 );
		}
		return $this->_category;
	}	
	
	function _getCategoryQuery( $categoryId, $aid, $params ) {

		$wheres[] = ' e.id= '.(int)$categoryId;
 		$query = Sql2excelQuery::getBaseQuery('DISTINCT e.id, e.title, e.description', $wheres, '');
 		
//echo '<hr>';
//echo str_replace('#__', 'jos_' , $nquery);
//echo '<hr>';
		return $query;
	}
	
	function getSection($categoryId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		if (empty($this->_category)) {	
			global $mainframe;
			$user 			= &JFactory::getUser();
			$aid 			= $user->get('aid', 0);			
			$query			= $this->_getSectionQuery( $categoryId, $aid, $params );
			$this->_section= $this->_getList( $query, 0, 1 );
		}
		return $this->_section;
	}
	
	function _getSectionQuery( $categoryId, $aid, $params ) {
		
		$wheres[]	= " cc.id= ".(int)$categoryId;
		$wheres[]	= " cc.section=s.id";
		if ($aid !== null) {
			$wheres[] = "cc.access <= " . (int) $aid;
			$wheres[] = "s.access <= " . (int) $aid;
		}
		$wheres[] = " cc.published = 1";
		
		$query = " SELECT s.id, s.title, s.alias"
				. " FROM #__sql2excel_sections AS s"
				. " ,#__sql2excel_categories AS cc"
				. " WHERE " . implode( " AND ", $wheres )
				. " ORDER BY cc.ordering";
		return $query;
	}
	
	function getDownload($id) {
		
		global $mainframe;
		$user		=& JFactory::getUser();
		$aid 		= $user->get('aid', 0);
		$outcome	= array();
		
		$wheres[]	= " c.id= ".(int)$id;
		
		// Get the file information and then check if it is possible for user download (so we can leave a message)
		//if ($aid !== null) {
		//	$wheres[] = "c.access <= " . (int) $aid;
		//}
		$wheres[] = " c.published = 1";
		
		
		$query = " SELECT c.filename, c.directlink, c.access"
				." FROM #__sql2excel_workbooks AS c"
				. " WHERE " . implode( " AND ", $wheres )
				. " ORDER BY c.ordering";
				
		$filename = $this->_getList( $query, 0, 1 );
		
		// - - - - - - - - - - - - - - - 
		if (empty($filename)) {
			$outcome['file'] 		= "PhocaErrorNoDBResult";
			$outcome['directlink']	= 0;
			return $outcome;
		} 
		
		if (isset($filename[0]->access)) {
			if ($aid !== null) {
				if ($filename[0]->access > (int) $aid) {
						$mainframe->redirect(JRoute::_('index.php?option=com_user&view=login', false), JText::_("Please login to download the file"));
						exit;
				}
			} else {
				$outcome['file'] 		= "PhocaErrorAidProblem";
				$outcome['directlink']	= 0;
				return $outcome;
			}
		} else {
			$outcome['file'] 		= "PhocaErrorNoDBResult";
			$outcome['directlink']	= 0;
			return $outcome;
		}
		// - - - - - - - - - - - - - - - -
		
		
		$this->_filename 	= $filename[0]->filename;
		$this->_directlink 	= $filename[0]->directlink;
		$filePath			= PhocaDownloadHelper::getPathSet('file');
		
		if ($this->_filename !='') {
			
			// Important - you cannot use direct link if you have selected absolute path
			// Absolute Path defined by user
			$absolutePath	= PhocaDownloadHelper::getSettings('absolute_path', '');
			if ($absolutePath != '') {
				$this->_directlink = 0;
			}
			
			if ($this->_directlink == 1 ) {
				$relFile = JURI::base(true).'/'.PhocaDownloadHelper::getSettings('download_folder', 'phocadownload' ).'/'.$this->_filename;
				$outcome['file'] 		= $relFile;
				$outcome['directlink']	= $this->_directlink;
				return $outcome;
			} else {
				$absFile = str_replace('/', DS, JPath::clean($filePath['orig_abs_ds'] . $this->_filename));
			}
			
			if (JFile::exists($absFile)) {
				$outcome['file'] 		= $absFile;
				$outcome['directlink']	= $this->_directlink;
				return $outcome;
			} else {
			
				$outcome['file'] 		= "PhocaErrorNoAbsFile";
				$outcome['directlink']	= 0;
				return $outcome;
			}
		} else {
		
				$outcome['file'] 		= "PhocaErrorNoDBFile";
				$outcome['directlink']	= 0;
				return $outcome;
		}
		
	}
	
	function _getFileOrdering() {
		if (empty($this->_file_ordering)) {	
			$params	= Sql2excelParms::getParms();
			$ordering = Sql2excelParms::get($params,'file_ordering', 1);			
			$this->_file_ordering 		= Sql2excelQuery::getOrderingText($ordering);
		}
		return $this->_file_ordering;
	}
}
?>