<?php
/*
 * @component SQL 2 Excel Pro Component
 * @copyright Copyright (C) Joomla-R-Us, joomla-r-us.com
 * @license http://www.gnu.org/licenses/gpl-3.0.html GNU/GPLv3
 *
 * Original code by Jan Pavelka (www.phoca.cz) 					
 * Adapted by Joomla-R-Us for SQl 2 Excel Pro
 *
 */
 
 /*
  * @package Joomla 1.5
  * @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
  * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
  *
  * @component Phoca Component
  * @copyright Copyright (C) Jan Pavelka www.phoca.cz
  * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport('joomla.application.component.model');


require_once( JPATH_COMPONENT.DS.'helpers'.DS.'query.php' );

class Sql2excelModelSection extends JModel
{
	var $_category 			= null;
	var $_section 			= null;
	var $_most_viewed_docs	= null;
	var $_category_ordering	= null;

	function __construct() {
		parent::__construct();
	}

	function getCategoryList($sectionId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		
		if (empty($this->_category)) {	
			global $mainframe;
			$user 			= &JFactory::getUser();
			$aid 			= $user->get('aid', 0);			
			$query			= $this->_getCategoryListQuery( $sectionId, $aid, $params );
			$this->_category= $this->_getList( $query );
		}
		return $this->_category;
	}
	
	function _getCategoryListQuery( $sectionId, $aid, $params ) {

		// Filter Sections / Categories ?
		$section_ids_where = $params->get( 'display_sections', '' );
		$section_ids_not_where = $params->get( 'hide_sections', '' );
		$category_ids_where = $params->get( 'display_categories', '' );
		$category_ids_not_where = $params->get( 'hide_categories', '' );

		$orderBy = $this->_getCategoryOrdering();

		$wheres[] = " a.section= ".(int)$sectionId;	
		$query = Sql2excelQuery::getBaseQuery(	"e.id, e.title ,e.alias, e.ordering, COUNT(distinct a.id) as numdoc", 
							$wheres, 
							'GROUP BY e.id',
							$orderBy,
							$section_ids_where,
							$section_ids_not_where,
							$category_ids_where,
							$category_ids_not_where);
							

		return $query;
	}
	
	function getSection($sectionId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		//$wheres[] = " cc.published = 1 ";	
		if (empty($this->_category)) {	
			global $mainframe;
			$user 			= &JFactory::getUser();
			$aid 			= $user->get('aid', 0);			
			$query			= $this->_getSectionQuery( $sectionId, $aid, $params );
			$this->_section= $this->_getList( $query, 0, 1 );
		}
		return $this->_section;
	}
	
	function _getSectionQuery( $sectionId, $aid, $params ) {
		
		$wheres[]	= " s.id= ".(int)$sectionId;
		if ($aid !== null) {
			$wheres[] = "s.access <= " . (int) $aid;
		}
		$wheres[] = " s.published = 1";
		
		$query = " SELECT s.id, s.title, s.description, s.alias"
				. " FROM #__sql2excel_sections AS s"
				. " WHERE " . implode( " AND ", $wheres )
				. " ORDER BY s.ordering";
		return $query;
	}
	
	
	function getMostViewedDocsList($sectionId, $params) {
		$user	=& JFactory::getUser();
		$aid 	= $user->get('aid', 0);	
		
		if (empty($this->_most_viewed_docs)) {	
			global $mainframe;
			$user 						= &JFactory::getUser();
			$aid 						= $user->get('aid', 0);			
			$query						= $this->_getMostViewedDocsListQuery( $sectionId, $aid, $params );
			$this->_most_viewed_docs 	= $this->_getList( $query );
		}
		return $this->_most_viewed_docs;
	}
	
	function _getMostViewedDocsListQuery( $sectionId, $aid, $params ) {
		
		// PARAMS
		$most_viewed_docs_num = $params->get( 'most_viewed_docs_num', 5 );
		
		$display_sections = $params->get('display_sections', '');
		if ( $display_sections != '' ) {
			$section_ids_where = " AND s.id IN (".$display_sections.")";
		} else {
			$section_ids_where = '';
		}
		
		$hide_sections = $params->get('hide_sections', '');
		if ( $hide_sections != '' ) {
			$section_ids_not_where = " AND s.id NOT IN (".$hide_sections.")";
		} else {
			$section_ids_not_where = '';
		}
		
		$wheres[]	= " c.sectionid= s.id";
		$wheres[]	= " c.catid= cc.id";
		$wheres[]	= " c.published= 1";
		$wheres[]	= " c.textonly= 0";
		if ($aid !== null) {
			$wheres[] = "c.access <= " . (int) $aid;
			$wheres[] = "s.access <= " . (int) $aid;
			$wheres[] = "cc.access <= " . (int) $aid;
		}
		$wheres[]	= " s.id= ".(int)$sectionId;
		
		$query = " SELECT c.id, c.title, c.alias, c.filename, c.date, c.hits, c.image_filename, s.title AS sectiontitle, cc.id AS categoryid, cc.title AS categorytitle, cc.alias AS categoryalias "
				." FROM #__phocadownload AS c, #__phocadownload_sections AS s, #__phocadownload_categories AS cc"
				. " WHERE " . implode( " AND ", $wheres )
				. $section_ids_where
				. $section_ids_not_where
				. " ORDER BY c.hits DESC"
				. " LIMIT ".(int)$most_viewed_docs_num;
		return $query;
	}
	
	function _getCategoryOrdering() {
		if (empty($this->_category_ordering)) {
	
			$params	= Sql2excelParms::getParms();
			$ordering = Sql2excelParms::get($params,'category_ordering', 1);			
			$this->_category_ordering = Sql2excelQuery::getOrderingText($ordering);

		}
		return $this->_category_ordering;
	}
}
?>