<?php
/**
 * This file contains the WeatherConfiguration class, which abstracts
 *  the configuration parameters for the eWeather component.
 *
 * This file is part of eWeather.
 *
 *   eWeather is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   eWeather is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with eWeather.  If not, see <a href="http://www.gnu.org/licenses/">
 *   http://www.gnu.org/licenses/</a>.
 *
 * <b>Modifications:</b><br/>
 * aangepast door Mart Dirks<br/>
 * converted to Joomla! 1.5.x by Bob Lavey
 *
 * @version $Id$
 * @package eWeather
 * @subpackage Admin eWeather
 * @copyright Copyright (c) 2000 - 2006 MamboBaer.de (Harald Baer),
 * 			  2007 Mart Dirks,<br/>
 *            2009 Bob Lavey<br/>
 * @license http://www.gnu.org/licenses/gpl.txt GNU/GPL
 * @toto Break this into additional classes: AdminWeatherConfigurationForm,
 *        AdminWeatherInstalledLocationForm, and AdminWeatherInfoForm.
 */

/* ensure this file is being called by Joomla! */
defined('_JEXEC') or die('Direct Access to this location is not allowed.');

/** @todo finish documentation */
class WeatherConfiguration
{
	var $eWeatherVersion_;
	var $partnerID_;
	var $partnerKey_;
	var $defaultLocation_;
	var $cacheTime_;
	var $units_;
	var $forecastDays_;
	var $forecastDaysPerRow_;
	var $headerPosition_;
	var $showFooter_;
	var $iconsStyle_;
	var $showForecast_;
	var $timeFormat_;
	var $dateFormatLong_;
	var $dateFormatShort_;
	var $dateFormatDetail_;
	var $useProxy_;
	var $proxyHost_;
	var $proxyPort_;
	var $useProxyAuth_;
	var $proxyAuthUser_;
	var $proxyAuthPwd_;
	
	var	$configFileName_ = null;
	
	function WeatherConfiguration()
	{
		$this->configFileName_ = JPATH_ADMINISTRATOR.DS."components/com_eweather/eweather.config.data.php";
	}

	function GetVersion() { return $this->eWeatherVersion_; }
	function GetPartnerID() { return $this->partnerID_; }
	function GetPartnerKey() { return $this->partnerKey_; }
	function GetDefaultLocation() { return $this->defaultLocation_; }
	function SetDefaultLocation($newDefaultLocation)
	{
		$this->defaultLocation_ = $newDefaultLocation;
	}
	function GetCacheTime() { return $this->cacheTime_; }
	function GetCacheTimeAsInt()
	{
		if ($this->cacheTime_ < 1800)
		{
			return 1800;
		}
		else
		{
			return $this->cacheTime_;
		}
	}
	function GetUnits() { return $this->units_; }
	function GetUnitsForWeatherChannel()
	{
		//
		// convert the units to a value The Weather Channel expects
		//
		if ($this->units_ == "0")
		{
			return "m";  // metric
		}
		else
		{
			return "s";  // standard
		}
	}
	function GetForecastDays() { return $this->forecastDays_; }
	function GetForecastDaysPerRow() { return $this->forecastDaysPerRow_; }
	function GetHeaderPosition() { return $this->headerPosition_; }
	function GetShowFooter() { return $this->showFooter_; }
	function GetIconsStyle() { return $this->iconsStyle_; }
	function GetShowForecast() { return $this->showForecast_; }
	function GetTimeFormat() { return $this->timeFormat_; }
	function GetDateFormatLong() { return $this->dateFormatLong_; }
	function GetDateFormatShort() { return $this->dateFormatShort_; }
	function GetDateFormatDetail() { return $this->dateFormatDetail_; }
	function GetUseProxy() { return $this->useProxy_; }
	function GetProxyHost() { return $this->proxyHost_; }
	function GetProxyPort() { return $this->proxyPort_; }
	function GetUseProxyAuth() { return $this->useProxyAuth_; }
	function GetProxyAuthUser() { return $this->proxyAuthUser_; }
	function GetProxyAuthPwd() { return $this->proxyAuthPwd_; }
	
	/** @todo finish documentation */
	function ReadFromConfigFile()
	{
		//
		// read configuration file
		//
		if (file_exists($this->configFileName_))
		{
			require($this->configFileName_);
		}
		else
		{
			die ("Error finding configuration file (".$this->configFileName_.")");
		}

		//
		// initialize our attributes from the configuration file
		//
		$this->eWeatherVersion_    = $weatherVersion;
		$this->partnerID_          = $weatherPartnerID;
		$this->partnerKey_         = $weatherPassword;
		$this->defaultLocation_    = $weatherDefaultLocationID;
		$this->cacheTime_          = $weatherCacheTime;
		$this->units_              = $weatherUnits;
		$this->forecastDays_       = $weatherDayForecast;
		$this->forecastDaysPerRow_ = $weatherForecastDaysPerRow;
		$this->headerPosition_     = $weatherHeaderPosition;
		$this->showFooter_         = $weatherShowFooter;
		$this->iconsStyle_         = $weatherIconsStyle;
		$this->showForecast_       = $weatherShowForecast;
		$this->timeFormat_         = $weatherTimeFormat;
		$this->dateFormatLong_     = $weatherLongDateFormat;
		$this->dateFormatShort_    = $weatherShortDateFormat;
		$this->dateFormatDetail_   = $weatherDetailDateFormat;
		$this->useProxy_           = $weatherUseProxy;
		$this->proxyHost_          = $weatherProxyHost;
		$this->proxyPort_          = $weatherProxyPort;
		$this->useProxyAuth_       = $weatherUseProxyAuth;
		$this->proxyAuthUser_      = $weatherProxyAuthUser;
		$this->proxyAuthPwd_       = $weatherProxyAuthPwd;
	}
	
	/** @todo finish documentation */
	function Dump()
	{
		echo "eWeatherVersion     ".$this->eWeatherVersion_."<br/>\n";
		echo "partnerID           ".$this->partnerID_."<br/>\n";
		echo "partnerKey          ".$this->partnerKey_."<br/>\n";
		echo "defaultLocation     ".$this->defaultLocation_."<br/>\n";
		echo "cacheTime           ".$this->cacheTime_."<br/>\n";
		echo "units               ".$this->units_."<br/>\n";
		echo "iconsStyle          ".$this->iconsStyle_."<br/>\n";
		echo "forecastDays        ".$this->forecastDays_."<br/>\n";
		echo "forecastDaysPerRow  ".$this->forecastDaysPerRow_."<br/>\n";
		echo "headerPosition      ".$this->headerPosition_."<br/>\n";
		echo "showFooter          ".$this->showFooter_."<br/>\n";
		echo "showForecast        ".$this->showForecast_."<br/>\n";
		echo "timeFormat          ".$this->timeFormat_."<br/>\n";
		echo "dateFormatLong      ".$this->dateFormatLong_."<br/>\n";
		echo "dateFormatShort     ".$this->dateFormatShort_."<br/>\n";
		echo "dateFormatDetail    ".$this->dateFormatDetail_."<br/>\n";
		echo "useProxy            ".$this->useProxy_."<br/>\n";
		echo "proxyHost           ".$this->proxyHost_."<br/>\n";
		echo "proxyPort           ".$this->proxyPort_."<br/>\n";
		echo "useProxyAuth        ".$this->useProxyAuth_."<br/>\n";
		echo "proxyAuthUser       ".$this->proxyAuthUser_."<br/>\n";
		echo "proxyAuthPwd        ".$this->proxyAuthPwd_."<br/>\n";
	}
}

?>