/**
 * Javascript file
 *
 * @package    Sourcerer
 * @version    2.0.1
 * @since      File available since Release 2.0.0
 *
 * @author     Peter van Westen <peter@nonumber.nl>
 * @link       http://www.nonumber.nl/sourcerer
 * @copyright  Copyright (C) 2009 NoNumber! All Rights Reserved
 * @license    http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

var old_source = '';

function sourcerer_initSource()
{
	var source_div = document.getElementById( 'source_div' );
	var source = source_div.innerHTML.trim();
	source_div.contentEditable = true;

	Browser = new Object();
	Browser.agt = navigator.userAgent.toLowerCase();
	Browser.is_ie = ( ( Browser.agt.indexOf( 'msie' ) != -1 ) && ( Browser.agt.indexOf( 'opera' ) == -1 ) );

	//Override if necessary

	var editor_textarea = window.parent.document.getElementById( sourcerer_editorname );
	var iframes = editor_textarea.parentNode.getElementsByTagName( 'iframe' );
	if ( !iframes.length ) { return; }

	var editor_frame = iframes[0];
    var contentWindow = editor_frame.contentWindow;

	var selection = '';
	if ( Browser.is_ie ) {
		selection = contentWindow.document.selection;
	} else {
		selection = contentWindow.getSelection();
	}

	selection = ( selection+'' ).trim();

	if ( selection != '' ) {
		selection = htmlentities( selection );
		source_div.innerHTML = selection;
	}
}

function sourcerer_convertText()
{
	f = document.getElementById( 'sourceForm');
	var source_div = document.getElementById( 'source_div' );
	var source = source_div.innerHTML.trim();

	tag_regex = new RegExp( '\\[\\[', 'g' );
	if ( source.search( tag_regex ) != -1 ) {
		sourcerer_toggleTagStyle( 0, 1 );
		source = source_div.innerHTML.trim();
	}

	window.parent.jInsertEditorText( source, sourcerer_editorname );
}

function sourcerer_colorizeTags( string, colorize )
{
	// convert cariage returns to html enters
	string = sourcerer_cleanBreaks( string );

	// remove all tags
	var regex = new RegExp( '<(/?\\w+((\\s+\\w+(\\s*=\\s*(?:"[\\s\\S.]*?"|\'[\\s\\S.]*?\'|[^\'">\\s]+))?)+\\s*|\\s*)/?)>', 'gm' );
	string = string.replace( regex, '' );

	// convert tabs to html spaces
	var regex = new RegExp( '\\t', 'g' );
	string = string.replace( regex, '&nbsp;&nbsp;&nbsp;&nbsp;' );
	// convert multiple spaces to html spaces
	var regex = new RegExp( '  ', 'g' );
	string = string.replace( regex, '&nbsp;&nbsp;' );

	if ( colorize == 1 ) {
		var code = '[\\s*]*[\\S.]*?[\\s\\S.]*?[\\S.]*?[\\s*]*';

		// color all code inside {source} tags
		var color = sourcerer_color_html;
		string = string.replace( '{source}', '{source}<span style="font-family:courier new,courier,monospace;color:'+color+';">' );
		string = string.replace( '{/source}', '</span>{/source}' );

		// color comment tags
		var color = sourcerer_color_comments;
		var replace_str = '<span style="color:'+color+';">\$1</span>'
		var regex = new RegExp( '(&lt;!--[\\s\\S.]*?--&gt;)', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(\\[\\[!--[\\s\\S.]*?--\\]\\])', 'gim' );
		string = string.replace( regex, replace_str );

		// color css tags
		var color = sourcerer_color_css;
		var replace_str = '<span style="color:'+color+';">\$1</span>'
		var regex = new RegExp( '(&lt;link [\\s\\S.]*?&gt;)', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(&lt;style [\\s\\S.]*?&gt;'+code+'&lt;/style&gt;)', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(\\[\\[link [\\s\\S.]*?\\]\\])', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(\\[\\[style [\\s\\S.]*?\\]\\]'+code+'\\[\\[/style\\]\\])', 'gim' );
		string = string.replace( regex, replace_str );

		// color javascript tags
		var color = sourcerer_color_js;
		var replace_str = '<span style="color:'+color+';">\$1</span>'
		var regex = new RegExp( '(&lt;script [\\s\\S.]*?&gt;'+code+'&lt;/script&gt;)', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(\\[\\[script [\\s\\S.]*?\\]\\]'+code+'\\[\\[/script\\]\\])', 'gim' );
		string = string.replace( regex, replace_str );

		// color php tags
		var color = sourcerer_color_php;
		var replace_str = '<span style="color:'+color+';">\$1</span>'
		var regex = new RegExp( '(&lt;\\?php[\\s*]'+code+'\\?&gt;)', 'gim' );
		string = string.replace( regex, replace_str );
		var regex = new RegExp( '(\\[\\[\\?php'+code+'\\?\\]\\])', 'gim' );
		string = string.replace( regex, replace_str );
	}

	// convert cariage returns to html enters
	string = sourcerer_insertBreaks( string );

	return string;
}

function sourcerer_cleanBreaks( string )
{
	// convert html enters to cariage returns
	var regex = new RegExp( '<br( \/)?>(\\n)*', 'gm' );
	string = string.replace( regex, '\n' );

	return string;
}

function sourcerer_insertBreaks( string )
{
	// convert cariage returns to html enters
	var regex = new RegExp( '\\n', 'g' );
	string = string.replace( regex, '<br />\n' );

	return string;
}

function sourcerer_toggleTags( setvalue, force )
{
	f = document.getElementById( 'sourceForm');
	var source_div = document.getElementById( 'source_div' );
	var source = source_div.innerHTML.trim();
	var button = document.getElementById( 'tags_button');

	if ( setvalue || force != 0 ) {

		source = sourcerer_colorizeTags( source, 0 );
		source = sourcerer_cleanBreaks( source );

		if ( force == 2 || ( !force && source.search( sourcerer_syntax_start ) != -1 ) ) {
			var regex = new RegExp( preg_quote( sourcerer_syntax_start )+'\\s*', 'gim' );
			source = source.replace( regex, '' );
			var regex = new RegExp( '\\s*'+preg_quote( sourcerer_syntax_end ), 'gim' );
			source = source.replace( regex, '' );
		} else if ( source.search( sourcerer_syntax_start ) == -1 ) {
			source = sourcerer_syntax_start+'\n'+source+'\n'+sourcerer_syntax_end;
		}

		source = sourcerer_insertBreaks( source );
		source = sourcerer_colorizeTags( source, f.colorizetags.value.trim() );

		source_div.innerHTML = source;
	}

	if( source.search( sourcerer_syntax_start ) != -1 ) {
		button.className = 'tags';
	} else {
		button.className = 'notags';
	}
}

function sourcerer_toggleTagStyle( setvalue, force )
{
	f = document.getElementById( 'sourceForm');
	var source_div = document.getElementById( 'source_div' );
	var source = source_div.innerHTML.trim();
	var button = document.getElementById( 'tagstyle_button');
	var tag_regex = new RegExp( '\\[\\[', 'g' );

	if ( setvalue || force ) {
		source = sourcerer_colorizeTags( source, 0 );
		source = sourcerer_cleanBreaks( source );

		if ( force == 2 || ( !force && source.search( tag_regex ) != -1 ) ) {
			source = source.replace( tag_regex, '&lt;' );
			var regex = new RegExp( '\\]\\]', 'g' );
			source = source.replace( regex, '&gt;' );
		} else {
			var regex = new RegExp( '&lt;(/?(\\!--\\s*)?\\w+((\\s+\\w+(\\s*=\\s*(?:"[\\s\\S.]*?"|\'[\\s\\S.]*?\'|[^\'">\\s]+))?)+\\s*|\\s*)(--|/)?)&gt;', 'gim' );
			source = source.replace( regex, '[[\$1]]' );
			var regex = new RegExp( '&lt;\\?(?:php)?([^a-z0-9])', 'gim' );
			source = source.replace( regex, '[[?php$1' );
			var regex = new RegExp( ' *\\?&gt;', 'g' );
			source = source.replace( regex, ' ?]]' );
		}

		source = sourcerer_insertBreaks( source );
		source = sourcerer_colorizeTags( source, f.colorizetags.value.trim() );

		source_div.innerHTML = source;
	}

	if ( source.search( tag_regex ) != -1 ) {
		button.className = 'brackets';
	} else {
		button.className = 'nobrackets';
	}
}

function sourcerer_toggleColorize( setvalue )
{
	f = document.getElementById( 'sourceForm');
	var source_div = document.getElementById( 'source_div' );
	var source = source_div.innerHTML.trim();
	var value = f.colorizetags.value.trim();
	var button = document.getElementById( 'colorize_button' );

	if ( setvalue ) {
		if ( value == 1 ) {
			value = 0;
		} else {
			value = 1;
		}
		f.colorizetags.value = value;
	}

	if ( value == 1 ) {
		button.className = 'colorize';
	} else {
		button.className = 'nocolorize';
	}

	source_div.innerHTML = sourcerer_colorizeTags( source, value );
}

function htmlentities( string, quote_style )
{
    var histogram = {}, symbol = '', tmp_str = '', entity = '';
    tmp_str = string.toString();

    if (false === (histogram = get_html_translation_table('HTML_ENTITIES', quote_style))) {
        return false;
    }

    for (symbol in histogram) {
        entity = histogram[symbol];
        tmp_str = tmp_str.split(symbol).join(entity);
    }

    return tmp_str;
}
function get_html_translation_table( table, quote_style )
{
    var entities = {}, histogram = {}, decimal = 0, symbol = '';
    var constMappingTable = {}, constMappingQuoteStyle = {};
    var useTable = {}, useQuoteStyle = {};

    // Translate arguments
    constMappingTable[0]      = 'HTML_SPECIALCHARS';
    constMappingTable[1]      = 'HTML_ENTITIES';
    constMappingQuoteStyle[0] = 'ENT_NOQUOTES';
    constMappingQuoteStyle[2] = 'ENT_COMPAT';
    constMappingQuoteStyle[3] = 'ENT_QUOTES';

    useTable     = !isNaN(table) ? constMappingTable[table] : table ? table.toUpperCase() : 'HTML_SPECIALCHARS';
    useQuoteStyle = !isNaN(quote_style) ? constMappingQuoteStyle[quote_style] : quote_style ? quote_style.toUpperCase() : 'ENT_COMPAT';

    if (useTable !== 'HTML_SPECIALCHARS' && useTable !== 'HTML_ENTITIES') {
        throw Error('Table: '+useTable+' not supported');
        // return false;
    }

    // ascii decimals for better compatibility
    entities['38'] = '&amp;';
    if (useQuoteStyle !== 'ENT_NOQUOTES') {
        entities['34'] = '&quot;';
    }
    if (useQuoteStyle === 'ENT_QUOTES') {
        entities['39'] = '&#039;';
    }
    entities['60'] = '&lt;';
    entities['62'] = '&gt;';

    if (useTable === 'HTML_ENTITIES') {
      entities['160'] = '&nbsp;';
      entities['161'] = '&iexcl;';
      entities['162'] = '&cent;';
      entities['163'] = '&pound;';
      entities['164'] = '&curren;';
      entities['165'] = '&yen;';
      entities['166'] = '&brvbar;';
      entities['167'] = '&sect;';
      entities['168'] = '&uml;';
      entities['169'] = '&copy;';
      entities['170'] = '&ordf;';
      entities['171'] = '&laquo;';
      entities['172'] = '&not;';
      entities['173'] = '&shy;';
      entities['174'] = '&reg;';
      entities['175'] = '&macr;';
      entities['176'] = '&deg;';
      entities['177'] = '&plusmn;';
      entities['178'] = '&sup2;';
      entities['179'] = '&sup3;';
      entities['180'] = '&acute;';
      entities['181'] = '&micro;';
      entities['182'] = '&para;';
      entities['183'] = '&middot;';
      entities['184'] = '&cedil;';
      entities['185'] = '&sup1;';
      entities['186'] = '&ordm;';
      entities['187'] = '&raquo;';
      entities['188'] = '&frac14;';
      entities['189'] = '&frac12;';
      entities['190'] = '&frac34;';
      entities['191'] = '&iquest;';
      entities['192'] = '&Agrave;';
      entities['193'] = '&Aacute;';
      entities['194'] = '&Acirc;';
      entities['195'] = '&Atilde;';
      entities['196'] = '&Auml;';
      entities['197'] = '&Aring;';
      entities['198'] = '&AElig;';
      entities['199'] = '&Ccedil;';
      entities['200'] = '&Egrave;';
      entities['201'] = '&Eacute;';
      entities['202'] = '&Ecirc;';
      entities['203'] = '&Euml;';
      entities['204'] = '&Igrave;';
      entities['205'] = '&Iacute;';
      entities['206'] = '&Icirc;';
      entities['207'] = '&Iuml;';
      entities['208'] = '&ETH;';
      entities['209'] = '&Ntilde;';
      entities['210'] = '&Ograve;';
      entities['211'] = '&Oacute;';
      entities['212'] = '&Ocirc;';
      entities['213'] = '&Otilde;';
      entities['214'] = '&Ouml;';
      entities['215'] = '&times;';
      entities['216'] = '&Oslash;';
      entities['217'] = '&Ugrave;';
      entities['218'] = '&Uacute;';
      entities['219'] = '&Ucirc;';
      entities['220'] = '&Uuml;';
      entities['221'] = '&Yacute;';
      entities['222'] = '&THORN;';
      entities['223'] = '&szlig;';
      entities['224'] = '&agrave;';
      entities['225'] = '&aacute;';
      entities['226'] = '&acirc;';
      entities['227'] = '&atilde;';
      entities['228'] = '&auml;';
      entities['229'] = '&aring;';
      entities['230'] = '&aelig;';
      entities['231'] = '&ccedil;';
      entities['232'] = '&egrave;';
      entities['233'] = '&eacute;';
      entities['234'] = '&ecirc;';
      entities['235'] = '&euml;';
      entities['236'] = '&igrave;';
      entities['237'] = '&iacute;';
      entities['238'] = '&icirc;';
      entities['239'] = '&iuml;';
      entities['240'] = '&eth;';
      entities['241'] = '&ntilde;';
      entities['242'] = '&ograve;';
      entities['243'] = '&oacute;';
      entities['244'] = '&ocirc;';
      entities['245'] = '&otilde;';
      entities['246'] = '&ouml;';
      entities['247'] = '&divide;';
      entities['248'] = '&oslash;';
      entities['249'] = '&ugrave;';
      entities['250'] = '&uacute;';
      entities['251'] = '&ucirc;';
      entities['252'] = '&uuml;';
      entities['253'] = '&yacute;';
      entities['254'] = '&thorn;';
      entities['255'] = '&yuml;';
    }

    // ascii decimals to real symbols
    for (decimal in entities) {
        symbol = String.fromCharCode(decimal);
        histogram[symbol] = entities[decimal];
    }

    return histogram;
}
function preg_quote( str ) {
    return (str+'').replace(/([\\\.\+\*\?\[\^\]\$\(\)\{\}\=\!<>\|\:])/g, "\\$1");
}

String.prototype.ltrim = function () { return this.replace(/^ */,""); }
String.prototype.rtrim = function () { return this.replace(/ *$/,""); }
String.prototype.trim = function () { return this.ltrim().rtrim(); }